@@ -30,18 +30,12 @@ creating, and deleting of databases.
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
-
 import os
 import sys
 import time
 import io
-if sys.version_info[0] < 3:
-    from urlparse import urlparse
-    from urllib2 import urlopen, url2pathname
-else:
-    from urllib.parse import urlparse
-    from urllib.request import urlopen, url2pathname
+from urllib.parse import urlparse
+from urllib.request import urlopen, url2pathname
 import tempfile
 #-------------------------------------------------------------------------
 #
@@ -63,7 +57,7 @@ _ = glocale.translation.gettext
 from gramps.gen.db import DbBsddb
 from gramps.gen.plug import BasePluginManager
 from gramps.gen.config import config
-from gramps.gen.constfunc import win, conv_to_unicode, UNITYPE
+from gramps.gen.constfunc import win, conv_to_unicode
 #-------------------------------------------------------------------------
 #
 # constants
@@ -144,10 +138,7 @@ class CLIDbManager(object):
         current DB.
         Returns ("Unknown", "Unknown", "Unknown") if invalid DB or other error.
         """
-        if config.get('preferences.use-bsddb3') or sys.version_info[0] >= 3:
-            from bsddb3 import dbshelve, db
-        else:
-            from bsddb import dbshelve, db
+        from bsddb3 import dbshelve, db
 
         from gramps.gen.db import META, PERSON_TBL
         from  gramps.gen.db.dbconst import BDBVERSFN
@@ -517,6 +508,6 @@ def find_locker_name(dirpath):
         # feature request 2356: avoid genitive form
         last = _("Locked by %s") % username
         ifile.close()
-    except (OSError, IOError):
+    except (OSError, IOError, UnicodeDecodeError):
         last = _("Unknown")
     return last
