@@ -32,7 +32,6 @@
 # Python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
 import traceback
 import os
 import sys
@@ -60,7 +59,6 @@ from gramps.gen.plug.report import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK,
 from gramps.gen.plug.report._paper import paper_sizes
 from gramps.gen.const import USER_HOME
 from gramps.gen.dbstate import DbState
-from gramps.gen.constfunc import STRTYPE, conv_to_unicode_direct
 from ..grampscli import CLIManager
 from ..user import User
 from gramps.gen.const import GRAMPS_LOCALE as glocale
@@ -78,13 +76,13 @@ def _convert_str_to_match_type(str_val, type_val):
     str_val = str_val.strip()
     ret_type = type(type_val)
     
-    if isinstance(type_val, STRTYPE):
+    if isinstance(type_val, str):
         if ( str_val.startswith("'") and str_val.endswith("'") ) or \
            ( str_val.startswith('"') and str_val.endswith('"') ):
             # Remove enclosing quotes
-            return conv_to_unicode_direct(str_val[1:-1])
+            return str(str_val[1:-1])
         else:
-            return conv_to_unicode_direct(str_val)
+            return str(str_val)
         
     elif ret_type == int:
         if str_val.isdigit():
@@ -227,7 +225,7 @@ class CommandLineReport(object):
         self.raw_name = name
         self.option_class = option_class(name, database)
         if category == CATEGORY_GRAPHVIZ:
-            # Need to include GraphViz options
+            # Need to include Graphviz options
             self.__gvoptions = graphdoc.GVOptions()
             menu = self.option_class.menu
             self.__gvoptions.add_menu_options(menu)
