@@ -49,7 +49,7 @@ class HasGalleryBase(Rule):
 
     def prepare(self, db):
         # things we want to do just once, not for every handle
-        if  self.list[1] == 'lesser than':
+        if  self.list[1] == 'less than':
             self.count_type = 0
         elif self.list[1] == 'greater than':
             self.count_type = 2
@@ -60,7 +60,7 @@ class HasGalleryBase(Rule):
         
     def apply(self, db, obj):
         count = len( obj.get_media_list())
-        if self.count_type == 0:     # "lesser than"
+        if self.count_type == 0:     # "less than"
             return count < self.userSelectedCount
         elif self.count_type == 2:   # "greater than"
             return count > self.userSelectedCount
