@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # gen.filters.rules/_HasLDSBase.py
 
@@ -52,7 +52,7 @@ class HasLDSBase(Rule):
     
     def prepare(self, db):
         # things we want to do just once, not for every handle
-        if  self.list[1] == 'lesser than':
+        if  self.list[1] == 'less than':
             self.count_type = 0
         elif self.list[1] == 'greater than':
             self.count_type = 2
@@ -63,7 +63,7 @@ class HasLDSBase(Rule):
         
     def apply(self, db, obj):
         count = len( obj.get_lds_ord_list())
-        if self.count_type == 0:     # "lesser than"
+        if self.count_type == 0:     # "less than"
             return count < self.userSelectedCount
         elif self.count_type == 2:   # "greater than"
             return count > self.userSelectedCount
