@@ -18,13 +18,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
-Family object for GRAMPS.
+Family object for Gramps.
 """
 
 #-------------------------------------------------------------------------
@@ -52,6 +50,7 @@ from .tagbase import TagBase
 from .childref import ChildRef
 from .familyreltype import FamilyRelType
 from .const import IDENTICAL, EQUAL, DIFFERENT
+from .handle import Handle
 
 #-------------------------------------------------------------------------
 #
@@ -59,18 +58,18 @@ from .const import IDENTICAL, EQUAL, DIFFERENT
 #
 #-------------------------------------------------------------------------
 class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
-             TagBase, PrimaryObject):
+             PrimaryObject):
     """
-    The Family record is the GRAMPS in-memory representation of the
+    The Family record is the Gramps in-memory representation of the
     relationships between people. It contains all the information
     related to the relationship.
     
     Family objects are usually created in one of two ways.
 
     1. Creating a new Family object, which is then initialized and
-        added to the database.
+       added to the database.
     2. Retrieving an object from the database using the records
-        handle.
+       handle.
 
     Once a Family object has been modified, it must be committed
     to the database using the database object's commit_family function,
@@ -90,7 +89,6 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         MediaBase.__init__(self)
         AttributeBase.__init__(self)
         LdsOrdBase.__init__(self)
-        TagBase.__init__(self)
         self.father_handle = None
         self.mother_handle = None
         self.child_ref_list = []
@@ -113,7 +111,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         a form that it can use.
 
         :returns: Returns a python tuple containing the data that should
-            be considered persistent.
+                  be considered persistent.
         :rtype: tuple
         """
         return (self.handle, self.gramps_id, self.father_handle,
@@ -148,10 +146,11 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :returns: Returns a struct containing the data of the object.
         :rtype: dict
         """
-        return {"handle": self.handle, 
+        return {"_class": "Family",
+                "handle": Handle("Family", self.handle), 
                 "gramps_id": self.gramps_id, 
-                "father_handle": self.father_handle,
-                "mother_handle": self.mother_handle,
+                "father_handle": Handle("Person", self.father_handle),
+                "mother_handle": Handle("Person", self.mother_handle),
                 "child_ref_list": [cr.to_struct() for cr in self.child_ref_list],
                 "type": self.type.to_struct(),
                 "event_ref_list": [er.to_struct() for er in self.event_ref_list],
@@ -164,6 +163,30 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                 "tag_list": TagBase.to_struct(self), 
                 "private": self.private}
 
+    @classmethod
+    def from_struct(cls, struct):
+        """
+        Given a struct data representation, return a serialized object.
+
+        :returns: Returns a serialized object
+        """
+        default = Family()
+        return (Handle.from_struct(struct.get("handle", default.handle)),
+                struct.get("gramps_id", default.gramps_id),
+                Handle.from_struct(struct.get("father_handle", default.father_handle)),
+                Handle.from_struct(struct.get("mother_handle", default.mother_handle)),
+                [ChildRef.from_struct(cr) for cr in struct.get("child_ref_list", default.child_ref_list)],
+                FamilyRelType.from_struct(struct.get("type", {})),
+                [EventRef.from_struct(er) for er in struct.get("event_ref_list", default.event_ref_list)],
+                MediaBase.from_struct(struct.get("media_list", default.media_list)),
+                AttributeBase.from_struct(struct.get("attribute_list", default.attribute_list)),
+                LdsOrdBase.from_struct(struct.get("lds_ord_list", default.lds_ord_list)),
+                CitationBase.from_struct(struct.get("citation_list", default.citation_list)),
+                NoteBase.from_struct(struct.get("note_list", default.note_list)),
+                struct.get("change", default.change), 
+                TagBase.from_struct(struct.get("tag_list", default.tag_list)), 
+                struct.get("private", default.private))
+
     def unserialize(self, data):
         """
         Convert the data held in a tuple created by the serialize method
@@ -198,7 +221,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :param handle: The handle to be checked.
         :type handle: str
         :returns: Returns whether the object has reference to this handle of 
-                this object type.
+                  this object type.
         :rtype: bool
         """
         if classname == 'Event':
@@ -316,7 +339,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Return the list of child secondary objects that may refer citations.
 
         :returns: Returns the list of child secondary child objects that may 
-                refer citations.
+                  refer citations.
         :rtype: list
         """
         check_list = self.media_list + self.attribute_list + \
@@ -328,7 +351,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Return the list of child secondary objects that may refer notes.
 
         :returns: Returns the list of child secondary child objects that may 
-                refer notes.
+                  refer notes.
         :rtype: list
         """
         check_list = self.media_list + self.attribute_list + \
@@ -371,7 +394,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Lost: handle, id, relation, father, mother of acquisition.
 
         :param acquisition: The family to merge with the present family.
-        :rtype acquisition: Family
+        :type acquisition: Family
         """
         if self.type != acquisition.type and self.type == FamilyRelType.UNKNOWN:
             self.set_relationship(acquisition.get_relationship())
@@ -393,22 +416,28 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         The type is a tuple whose first item is an integer constant and whose 
         second item is the string. The valid values are:
 
-            - C{FamilyRelType.MARRIED} : indicates a legally recognized married
-                relationship between two individuals. This may be either
-                an opposite or a same sex relationship.
-            - C{FamilyRelType.UNMARRIED} : indicates a relationship between two
-                individuals that is not a legally recognized relationship.
-            - C{FamilyRelType.CIVIL_UNION} : indicates a legally recongnized,
-                non-married relationship between two individuals of the
-                same sex.
-            - C{FamilyRelType.UNKNOWN} : indicates that the type of relationship
-                between the two individuals is not know.
-            - C{FamilyRelType.CUSTOM} : indicates that the type of relationship
-                between the two individuals does not match any of the
-                other types.
+        =========================  ============================================ 
+        Type                       Description
+        =========================  ============================================ 
+        FamilyRelType.MARRIED      indicates a legally recognized married
+                                   relationship between two individuals. This
+                                   may be either an opposite or a same sex
+                                   relationship.
+        FamilyRelType.UNMARRIED    indicates a relationship between two
+                                   individuals that is not a legally recognized
+                                   relationship.
+        FamilyRelType.CIVIL_UNION  indicates a legally recongnized, non-married
+                                   relationship between two individuals of the
+                                   same sex.
+        FamilyRelType.UNKNOWN      indicates that the type of relationship
+                                   between the two individuals is not know.
+        FamilyRelType.CUSTOM       indicates that the type of relationship
+                                   between the two individuals does not match
+                                   any of the other types.
+        =========================  ============================================ 
 
         :param relationship_type: (int,str) tuple of the relationship type
-            between the father and mother of the relationship.
+               between the father and mother of the relationship.
         :type relationship_type: tuple
         """
         self.type.set(relationship_type)
@@ -422,53 +451,54 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
     def set_father_handle(self, person_handle):
         """
-        Set the database handle for :class:`~gen.lib.person.Person` that corresponds to male of the 
-        relationship. 
+        Set the database handle for :class:`~.person.Person` that corresponds 
+        to male of the relationship. 
         
         For a same sex relationship, this can represent either of people 
         involved in the relationship.
 
-        :param person_handle: :class:`~gen.lib.person.Person` database handle
+        :param person_handle: :class:`~.person.Person` database handle
         :type person_handle: str
         """
         self.father_handle = person_handle
 
     def get_father_handle(self):
         """
-        Return the database handle of the :class:`~gen.lib.person.Person` identified as the father 
-        of the Family.
+        Return the database handle of the :class:`~.person.Person` identified 
+        as the father of the Family.
 
-        :returns: :class:`~gen.lib.person.Person` database handle
+        :returns: :class:`~.person.Person` database handle
         :rtype: str
         """
         return self.father_handle
 
     def set_mother_handle(self, person_handle):
         """
-        Set the database handle for :class:`~gen.lib.person.Person` that corresponds to male of the 
-        relationship. 
+        Set the database handle for :class:`~.person.Person` that corresponds 
+        to male of the relationship. 
         
         For a same sex relationship, this can represent either of people 
         involved in the relationship.
 
-        :param person_handle: :class:`~gen.lib.person.Person` database handle
+        :param person_handle: :class:`~.person.Person` database handle
         :type person_handle: str
         """
         self.mother_handle = person_handle
 
     def get_mother_handle(self):
         """
-        Return the database handle of the :class:`~gen.lib.person.Person` identified as the mother 
-        of the Family.
+        Return the database handle of the :class:`~.person.Person` identified 
+        as the mother of the Family.
 
-        :returns: :class:`~gen.lib.person.Person` database handle
+        :returns: :class:`~.person.Person` database handle
         :rtype: str
         """
         return self.mother_handle
 
     def add_child_ref(self, child_ref):
         """
-        Add the database handle for :class:`~gen.lib.person.Person` to the Family's list of children.
+        Add the database handle for :class:`~.person.Person` to the Family's
+        list of children.
 
         :param child_ref: Child Reference instance
         :type  child_ref: ChildRef
@@ -479,13 +509,13 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
             
     def remove_child_ref(self, child_ref):
         """
-        Remove the database handle for :class:`~gen.lib.person.Person` to the Family's list of 
-        children if the :class:`~gen.lib.person.Person` is already in the list.
+        Remove the database handle for :class:`~.person.Person` to the Family's
+        list of children if the :class:`~.person.Person` is already in the list.
 
         :param child_ref: Child Reference instance
         :type child_ref: ChildRef
         :returns: True if the handle was removed, False if it was not
-            in the list.
+                  in the list.
         :rtype: bool
         """
         if not isinstance(child_ref, ChildRef):
@@ -496,13 +526,13 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
     def remove_child_handle(self, child_handle):
         """
-        Remove the database handle for :class:`~gen.lib.person.Person` to the Family's list of 
-        children if the :class:`~gen.lib.person.Person` is already in the list.
+        Remove the database handle for :class:`~.person.Person` to the Family's
+        list of children if the :class:`~.person.Person` is already in the list.
 
-        :param child_handle: :class:`~gen.lib.person.Person` database handle
+        :param child_handle: :class:`~.person.Person` database handle
         :type  child_handle: str
         :returns: True if the handle was removed, False if it was not
-            in the list.
+                  in the list.
         :rtype: bool
         """
         new_list = [ref for ref in self.child_ref_list
@@ -511,11 +541,11 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
     def get_child_ref_list(self):
         """
-        Return the list of :class:`~gen.lib.childref.ChildRef` handles identifying the children of the 
-        Family.
+        Return the list of :class:`~.childref.ChildRef` handles identifying the
+        children of the Family.
 
-        :returns: Returns the list of :class:`~gen.lib.childref.ChildRef` handles associated with
-            the Family.
+        :returns: Returns the list of :class:`~.childref.ChildRef` handles
+                  associated with the Family.
         :rtype: list
         """
         return self.child_ref_list
@@ -526,7 +556,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
         :param child_ref_list: List of Child Reference instances to be
                                associated as the Family's list of children.
-        :type child_ref_list: list of :class:`~gen.lib.childref.ChildRef` instances
+        :type child_ref_list: list of :class:`~.childref.ChildRef` instances
         """
         self.child_ref_list = child_ref_list
 
@@ -535,8 +565,8 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Merge the list of child references from acquisition with our own.
 
         :param acquisition: the childref list of this family will be merged
-            with the current childref list.
-        :rtype acquisition: Family
+                            with the current childref list.
+        :type acquisition: Family
         """
         childref_list = self.child_ref_list[:]
         for addendum in acquisition.get_child_ref_list():
@@ -552,13 +582,14 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
     def add_event_ref(self, event_ref):
         """
-        Add the :class:`~gen.lib.eventref.EventRef` to the Family instance's :class:`~gen.lib.eventref.EventRef` list.
+        Add the :class:`~.eventref.EventRef` to the Family instance's
+        :class:`~.eventref.EventRef` list.
         
-        This is accomplished by assigning the :class:`~gen.lib.eventref.EventRef` for the valid
-        :class:`~gen.lib.event.Event` in the current database.
+        This is accomplished by assigning the :class:`~.eventref.EventRef` for
+        the valid :class:`~.event.Event` in the current database.
         
-        :param event_ref: the :class:`~gen.lib.eventref.EventRef` to be added to the
-            Person's :class:`~gen.lib.eventref.EventRef` list.
+        :param event_ref: the :class:`~.eventref.EventRef` to be added to the
+                          Person's :class:`~.eventref.EventRef` list.
         :type event_ref: EventRef
         """
         if event_ref and not isinstance(event_ref, EventRef):
@@ -577,20 +608,22 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
 
     def get_event_ref_list(self) :
         """
-        Return the list of :class:`~gen.lib.eventref.EventRef` objects associated with :class:`~gen.lib.event.Event`
-        instances.
+        Return the list of :class:`~.eventref.EventRef` objects associated with
+        :class:`~.event.Event` instances.
 
-        :returns: Returns the list of :class:`~gen.lib.eventref.EventRef` objects associated with
-            the Family instance.
+        :returns: Returns the list of :class:`~.eventref.EventRef` objects 
+                  associated with the Family instance.
         :rtype: list
         """
         return self.event_ref_list
 
     def set_event_ref_list(self, event_ref_list) :
         """
-        Set the Family instance's :class:`~gen.lib.eventref.EventRef` list to the passed list.
+        Set the Family instance's :class:`~.eventref.EventRef` list to the
+        passed list.
 
-        :param event_ref_list: List of valid :class:`~gen.lib.eventref.EventRef` objects
+        :param event_ref_list: List of valid :class:`~.eventref.EventRef`
+                               objects
         :type event_ref_list: list
         """
         self.event_ref_list = event_ref_list
@@ -600,8 +633,8 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         Merge the list of event references from acquisition with our own.
 
         :param acquisition: the event references list of this object will be
-            merged with the current event references list.
-        :rtype acquisition: Person
+                            merged with the current event references list.
+        :type acquisition: Person
         """
         eventref_list = self.event_ref_list[:]
         for addendum in acquisition.get_event_ref_list():
@@ -614,4 +647,3 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
                     break
             else:
                 self.event_ref_list.append(addendum)
-
