@@ -23,7 +23,7 @@
 import unittest
 
 from  .. import (Person, Surname, Name, NameType, Family, FamilyRelType,
-                 Event, EventType, Source, Place, Citation, Date,
+                 Event, EventType, Source, Place, PlaceName, Citation, Date,
                  Repository, RepositoryType, MediaObject, Note, NoteType,
                  StyledText, StyledTextTag, StyledTextTagType, Tag,
                  ChildRef, ChildRefType, Attribute, MediaRef, AttributeType,
@@ -1011,6 +1011,10 @@ class NoteBaseCheck(unittest.TestCase):
         self.assertEqual(self.phoenix.serialize(), ref_note_list.serialize())
 
     def todo_test_replace_child(self):
+        ref_note_list = NoteBase()
+        note = Note("")
+        note.set_handle('123456')
+        ref_note_list.add_note(note.get_handle())
         self.phoenix.replace_note_references('','')
         self.assertEqual(self.phoenix.serialize(), ref_note_list.serialize())
 
@@ -1387,100 +1391,108 @@ class PlaceCheck(unittest.TestCase, PrivacyBaseTest, MediaBaseTest,
         self.phoenix.set_title('Place 1')
         self.titanic = Place(self.phoenix)
         self.ref_obj = Place(self.phoenix)
+        self.amsterdam = PlaceName()
+        self.amsterdam.set_value('Amsterdam')
+        self.rotterdam = PlaceName()
+        self.rotterdam.set_value('Rotterdam')
+        self.utrecht = PlaceName()
+        self.utrecht.set_value('Utrecht')
+        self.leiden = PlaceName()
+        self.leiden.set_value('Leiden')
 
     def test_merge_primary_identical(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Amsterdam')
+        self.titanic.set_name(self.amsterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.ref_obj.set_name('Amsterdam')
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_primary_different(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Rotterdam')
+        self.titanic.set_name(self.rotterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.ref_obj.set_name('Amsterdam')
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Rotterdam')
+        self.ref_obj.add_alternative_name(self.rotterdam)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_both_different(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
-        self.phoenix.add_alternative_name('Utrecht')
+        self.phoenix.add_alternative_name(self.utrecht)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Rotterdam')
+        self.titanic.set_name(self.rotterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.titanic.add_alternative_name('Leiden')
-        self.ref_obj.set_name('Amsterdam')
+        self.titanic.add_alternative_name(self.leiden)
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Amsterdam')
-        self.ref_obj.add_alternative_name('Rotterdam')
-        self.ref_obj.add_alternative_name('Utrecht')
-        self.ref_obj.add_alternative_name('Leiden')
+        self.ref_obj.add_alternative_name(self.amsterdam)
+        self.ref_obj.add_alternative_name(self.rotterdam)
+        self.ref_obj.add_alternative_name(self.utrecht)
+        self.ref_obj.add_alternative_name(self.leiden)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_alternative_identical(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
-        self.phoenix.add_alternative_name('Rotterdam')
+        self.phoenix.add_alternative_name(self.rotterdam)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Amsterdam')
+        self.titanic.set_name(self.amsterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.titanic.add_alternative_name('Rotterdam')
-        self.ref_obj.set_name('Amsterdam')
+        self.titanic.add_alternative_name(self.rotterdam)
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Rotterdam')
+        self.ref_obj.add_alternative_name(self.rotterdam)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_alternative_different(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
-        self.phoenix.add_alternative_name('Rotterdam')
+        self.phoenix.add_alternative_name(self.rotterdam)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Amsterdam')
+        self.titanic.set_name(self.amsterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.titanic.add_alternative_name('Utrecht')
-        self.ref_obj.set_name('Amsterdam')
+        self.titanic.add_alternative_name(self.utrecht)
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Rotterdam')
-        self.ref_obj.add_alternative_name('Utrecht')
+        self.ref_obj.add_alternative_name(self.rotterdam)
+        self.ref_obj.add_alternative_name(self.utrecht)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_prialt_identical(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
-        self.phoenix.add_alternative_name('Rotterdam')
+        self.phoenix.add_alternative_name(self.rotterdam)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Rotterdam')
+        self.titanic.set_name(self.rotterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.ref_obj.set_name('Amsterdam')
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Rotterdam')
+        self.ref_obj.add_alternative_name(self.rotterdam)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
     def test_merge_prialt2(self):
-        self.phoenix.set_name('Amsterdam')
+        self.phoenix.set_name(self.amsterdam)
         self.phoenix.set_type(PlaceType.CITY)
-        self.phoenix.add_alternative_name('Rotterdam')
+        self.phoenix.add_alternative_name(self.rotterdam)
         self.titanic.set_title('Place 2')
-        self.titanic.set_name('Rotterdam')
+        self.titanic.set_name(self.rotterdam)
         self.titanic.set_type(PlaceType.CITY)
-        self.titanic.add_alternative_name('Amsterdam')
-        self.ref_obj.set_name('Amsterdam')
+        self.titanic.add_alternative_name(self.amsterdam)
+        self.ref_obj.set_name(self.amsterdam)
         self.ref_obj.set_type(PlaceType.CITY)
-        self.ref_obj.add_alternative_name('Rotterdam')
+        self.ref_obj.add_alternative_name(self.rotterdam)
         self.phoenix.merge(self.titanic)
         self.assertEqual(self.phoenix.serialize(), self.ref_obj.serialize())
 
