@@ -29,8 +29,6 @@ and a register for the data of all plugins .
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
-
 import os
 import sys
 import re
@@ -46,7 +44,6 @@ from gramps.version import VERSION as GRAMPSVERSION, VERSION_TUPLE
 from ..const import IMAGE_DIR
 from ..const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
-from ..constfunc import STRTYPE
 
 #-------------------------------------------------------------------------
 #
@@ -164,7 +161,7 @@ def valid_plugin_version(plugin_version_string):
     Checks to see if string is a valid version string for this version
     of Gramps.
     """
-    if not isinstance(plugin_version_string, STRTYPE): return False
+    if not isinstance(plugin_version_string, str): return False
     dots = plugin_version_string.count(".")
     if dots == 1:
         plugin_version  = tuple(map(int, plugin_version_string.split(".", 1)))
@@ -843,8 +840,7 @@ class PluginData(object):
     def _set_gramplet_title(self, gramplet_title):
         if not self._ptype == GRAMPLET:
             raise ValueError('gramplet_title may only be set for GRAMPLET plugins')
-        if not (sys.version_info[0] < 3 and isinstance(gramplet_title, unicode)
-                or isinstance(gramplet_title, str)):
+        if not isinstance(gramplet_title, str):
             raise ValueError('gramplet_title is type %s, string or unicode required' % type(gramplet_title))
         self._gramplet_title = gramplet_title
     
@@ -1100,10 +1096,13 @@ class PluginRegister(object):
                 continue
             lenpd = len(self.__plugindata)
             full_filename = os.path.join(dir, filename)
-            if sys.version_info[0] < 3:
-                fd = open(full_filename, "r")
-            else:
+            try:
                 fd = io.open(full_filename, "r", encoding='utf-8')
+            except Exception as msg:
+                print(_('ERROR: Failed reading plugin registration %(filename)s') % \
+                            {'filename' : filename})
+                print(msg)
+                continue
             stream = fd.read()
             fd.close()
             if os.path.exists(os.path.join(os.path.dirname(full_filename),
