@@ -17,13 +17,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 """
-Proxy class for the GRAMPS databases. Filter out all data marked private.
+Proxy class for the Gramps databases. Filter out all data marked private.
 """
 
 #-------------------------------------------------------------------------
@@ -43,7 +41,8 @@ LOG = logging.getLogger(".citation")
 #-------------------------------------------------------------------------
 from ..lib import (MediaRef, Attribute, Address, EventRef, 
                    Person, Name, Source, RepoRef, MediaObject, Place, Event, 
-                   Family, ChildRef, Repository, LdsOrd, Surname, Citation)
+                   Family, ChildRef, Repository, LdsOrd, Surname, Citation,
+                   SrcAttribute, Note, Tag)
 from .proxybase import ProxyDbBase
 
 class PrivateProxyDb(ProxyDbBase):
@@ -57,10 +56,90 @@ class PrivateProxyDb(ProxyDbBase):
         Create a new PrivateProxyDb instance. 
         """
         ProxyDbBase.__init__(self, db)
+        self._tables['Person'].update(
+            {
+                "handle_func": self.get_person_from_handle, 
+                "gramps_id_func": self.get_person_from_gramps_id,
+                "class_func": Person,
+                "cursor_func": self.get_person_cursor,
+                "handles_func": self.get_person_handles,
+            })
+        self._tables['Family'].update(
+            {
+                "handle_func": self.get_family_from_handle, 
+                "gramps_id_func": self.get_family_from_gramps_id,
+                "class_func": Family,
+                "cursor_func": self.get_family_cursor,
+                "handles_func": self.get_family_handles,
+            })
+        self._tables['Source'].update(
+            {
+                "handle_func": self.get_source_from_handle, 
+                "gramps_id_func": self.get_source_from_gramps_id,
+                "class_func": Source,
+                "cursor_func": self.get_source_cursor,
+                "handles_func": self.get_source_handles,
+                })
+        self._tables['Citation'].update(
+            {
+                "handle_func": self.get_citation_from_handle, 
+                "gramps_id_func": self.get_citation_from_gramps_id,
+                "class_func": Citation,
+                "cursor_func": self.get_citation_cursor,
+                "handles_func": self.get_citation_handles,
+            })
+        self._tables['Event'].update(
+            {
+                "handle_func": self.get_event_from_handle, 
+                "gramps_id_func": self.get_event_from_gramps_id,
+                "class_func": Event,
+                "cursor_func": self.get_event_cursor,
+                "handles_func": self.get_event_handles,
+            })
+        self._tables['Media'].update(
+            {
+                "handle_func": self.get_object_from_handle, 
+                "gramps_id_func": self.get_object_from_gramps_id,
+                "class_func": MediaObject,
+                "cursor_func": self.get_media_cursor,
+                "handles_func": self.get_media_object_handles,
+            })
+        self._tables['Place'].update(
+            {
+                "handle_func": self.get_place_from_handle, 
+                "gramps_id_func": self.get_place_from_gramps_id,
+                "class_func": Place,
+                "cursor_func": self.get_place_cursor,
+                "handles_func": self.get_place_handles,
+            })
+        self._tables['Repository'].update(
+            {
+                "handle_func": self.get_repository_from_handle, 
+                "gramps_id_func": self.get_repository_from_gramps_id,
+                "class_func": Repository,
+                "cursor_func": self.get_repository_cursor,
+                "handles_func": self.get_repository_handles,
+            })
+        self._tables['Note'].update(
+            {
+                "handle_func": self.get_note_from_handle, 
+                "gramps_id_func": self.get_note_from_gramps_id,
+                "class_func": Note,
+                "cursor_func": self.get_note_cursor,
+                "handles_func": self.get_note_handles,
+            })
+        self._tables['Tag'].update(
+            {
+                "handle_func": self.get_tag_from_handle, 
+                "gramps_id_func": None,
+                "class_func": Tag,
+                "cursor_func": self.get_tag_cursor,
+                "handles_func": self.get_tag_handles,
+            })
 
     def get_person_from_handle(self, handle):
         """
-        Finds a Person in the database from the passed gramps' ID.
+        Finds a Person in the database from the passed Gramps ID.
         If no such Person exists, None is returned.
         """
         person = self.db.get_person_from_handle(handle)
@@ -70,7 +149,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_source_from_handle(self, handle):
         """
-        Finds a Source in the database from the passed gramps' ID.
+        Finds a Source in the database from the passed Gramps ID.
         If no such Source exists, None is returned.
         """
         source = self.db.get_source_from_handle(handle)
@@ -80,7 +159,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_citation_from_handle(self, handle):
         """
-        Finds a Citation in the database from the passed gramps' ID.
+        Finds a Citation in the database from the passed Gramps ID.
         If no such Citation exists, None is returned.
         """
         citation = self.db.get_citation_from_handle(handle)
@@ -90,7 +169,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_object_from_handle(self, handle):
         """
-        Finds an Object in the database from the passed gramps' ID.
+        Finds an Object in the database from the passed Gramps ID.
         If no such Object exists, None is returned.
         """
         media = self.db.get_object_from_handle(handle)
@@ -100,7 +179,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_place_from_handle(self, handle):
         """
-        Finds a Place in the database from the passed gramps' ID.
+        Finds a Place in the database from the passed Gramps ID.
         If no such Place exists, None is returned.
         """
         place = self.db.get_place_from_handle(handle)
@@ -110,7 +189,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_event_from_handle(self, handle):
         """
-        Finds a Event in the database from the passed gramps' ID.
+        Finds a Event in the database from the passed Gramps ID.
         If no such Event exists, None is returned.
         """
         event = self.db.get_event_from_handle(handle)
@@ -120,7 +199,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_family_from_handle(self, handle):
         """
-        Finds a Family in the database from the passed gramps' ID.
+        Finds a Family in the database from the passed Gramps ID.
         If no such Family exists, None is returned.
         """
         family = self.db.get_family_from_handle(handle)
@@ -130,7 +209,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_repository_from_handle(self, handle):
         """
-        Finds a Repository in the database from the passed gramps' ID.
+        Finds a Repository in the database from the passed Gramps ID.
         If no such Repository exists, None is returned.
         """
         repository = self.db.get_repository_from_handle(handle)
@@ -140,7 +219,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_note_from_handle(self, handle):
         """
-        Finds a Note in the database from the passed gramps' ID.
+        Finds a Note in the database from the passed Gramps ID.
         If no such Note exists, None is returned.
         """
         note = self.db.get_note_from_handle(handle)
@@ -180,7 +259,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_place_from_gramps_id(self, val):
         """
-        Finds a Place in the database from the passed gramps' ID.
+        Finds a Place in the database from the passed Gramps ID.
         If no such Place exists, None is returned.
         """
         place = self.db.get_place_from_gramps_id(val)
@@ -190,7 +269,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_source_from_gramps_id(self, val):
         """
-        Finds a Source in the database from the passed gramps' ID.
+        Finds a Source in the database from the passed Gramps ID.
         If no such Source exists, None is returned.
         """
         source = self.db.get_source_from_gramps_id(val)
@@ -200,7 +279,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_citation_from_gramps_id(self, val):
         """
-        Finds a Citation in the database from the passed gramps' ID.
+        Finds a Citation in the database from the passed Gramps ID.
         If no such Citation exists, None is returned.
         """
         citation = self.db.get_citation_from_gramps_id(val)
@@ -210,7 +289,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_object_from_gramps_id(self, val):
         """
-        Finds a MediaObject in the database from the passed gramps' ID.
+        Finds a MediaObject in the database from the passed Gramps ID.
         If no such MediaObject exists, None is returned.
         """
         obj = self.db.get_object_from_gramps_id(val)
@@ -220,7 +299,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_repository_from_gramps_id(self, val):
         """
-        Finds a Repository in the database from the passed gramps' ID.
+        Finds a Repository in the database from the passed Gramps ID.
         If no such Repository exists, None is returned.
         """
         repository = self.db.get_repository_from_gramps_id(val)
@@ -230,7 +309,7 @@ class PrivateProxyDb(ProxyDbBase):
 
     def get_note_from_gramps_id(self, val):
         """
-        Finds a Note in the database from the passed gramps' ID.
+        Finds a Note in the database from the passed Gramps ID.
         If no such Note exists, None is returned.
         """
         note = self.db.get_note_from_gramps_id(val)
@@ -404,11 +483,11 @@ class PrivateProxyDb(ProxyDbBase):
         Find all objects that hold a reference to the object handle.
         Returns an iterator over a list of (class_name, handle) tuples.
 
-        @param handle: handle of the object to search for.
-        @type handle: database handle
-        @param include_classes: list of class names to include in the results.
+        :param handle: handle of the object to search for.
+        :type handle: database handle
+        :param include_classes: list of class names to include in the results.
                                 Default: None means include all classes.
-        @type include_classes: list of class names
+        :type include_classes: list of class names
         
         This default implementation does a sequential scan through all
         the primary object databases and is very slow. Backends can
@@ -416,7 +495,7 @@ class PrivateProxyDb(ProxyDbBase):
         make use of additional capabilities of the backend.
 
         Note that this is a generator function, it returns a iterator for
-        use in loops. If you want a list of the results use:
+        use in loops. If you want a list of the results use::
 
         >    result_list = list(find_backlink_handles(handle))
         """
@@ -452,13 +531,13 @@ def copy_media_ref_list(db, original_obj, clean_obj):
     Copies media references from one object to another - excluding private 
     references and references to private objects.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have private references
-    @type original_obj: MediaBase
-    @param clean_obj: Object that will have only non-private references
-    @type original_obj: MediaBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: MediaBase
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: MediaBase
+    :returns: Nothing
     """
     for media_ref in original_obj.get_media_list():
         if media_ref and not media_ref.get_privacy():
@@ -473,13 +552,13 @@ def copy_citation_ref_list(db, original_obj, clean_obj):
     to private citations, and references to citations that refer to private
     sources.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have private references
-    @type original_obj: CitationBase
-    @param clean_obj: Object that will have only non-private references
-    @type original_obj: CitationBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: CitationBase
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: CitationBase
+    :returns: Nothing
     """
     for citation_handle in original_obj.get_citation_list():
         citation = db.get_citation_from_handle(citation_handle)
@@ -494,13 +573,13 @@ def copy_notes(db, original_obj, clean_obj):
     Copies notes from one object to another - excluding references to private
     notes.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have private references
-    @type original_obj: NoteBase
-    @param clean_obj: Object that will have only non-private references
-    @type original_obj: NoteBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: NoteBase
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: NoteBase
+    :returns: Nothing
     """     
     for note_handle in original_obj.get_note_list():
         note = db.get_note_from_handle(note_handle)
@@ -512,13 +591,13 @@ def copy_associations(db, original_obj, clean_obj):
     Copies associations from one object to another - excluding
     references to private notes.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have private references
-    @type original_obj: Base
-    @param clean_obj: Object that will have only non-private references
-    @type original_obj: Base
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: Base
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: Base
+    :returns: Nothing
     """
     new_person_ref_list = []
     for person_ref in original_obj.get_person_ref_list():
@@ -527,19 +606,19 @@ def copy_associations(db, original_obj, clean_obj):
             if associated_person and not associated_person.get_privacy():
                 new_person_ref_list.append(person_ref)
     clean_obj.set_person_ref_list(new_person_ref_list)
-            
+
 def copy_attributes(db, original_obj, clean_obj):
     """
     Copies attributes from one object to another - excluding references to 
     private attributes.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have private references
-    @type original_obj: AttributeBase
-    @param clean_obj: Object that will have only non-private references
-    @type original_obj: AttributeBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: AttributeBase
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: AttributeBase
+    :returns: Nothing
     """   
     for attribute in original_obj.get_attribute_list():
         if attribute and not attribute.get_privacy():
@@ -549,19 +628,39 @@ def copy_attributes(db, original_obj, clean_obj):
             copy_notes(db, attribute, new_attribute)
             copy_citation_ref_list(db, attribute, new_attribute)
             clean_obj.add_attribute(new_attribute)
-      
+
+def copy_srcattributes(db, original_obj, clean_obj):
+    """
+    Copies srcattributes from one object to another - excluding references to 
+    private srcattributes.
+
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have private references
+    :type original_obj: SrcAttributeBase
+    :param clean_obj: Object that will have only non-private references
+    :type original_obj: SrcAttributeBase
+    :returns: Nothing
+    """   
+    for attribute in original_obj.get_attribute_list():
+        if attribute and not attribute.get_privacy():
+            new_attribute = SrcAttribute()
+            new_attribute.set_type(attribute.get_type())
+            new_attribute.set_value(attribute.get_value())
+            clean_obj.add_attribute(new_attribute)
+
 def copy_urls(db, original_obj, clean_obj):
     """
     Copies urls from one object to another - excluding references to 
     private urls.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have urls
-    @type original_obj: UrlBase
-    @param clean_obj: Object that will have only non-private urls
-    @type original_obj: UrlBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have urls
+    :type original_obj: UrlBase
+    :param clean_obj: Object that will have only non-private urls
+    :type original_obj: UrlBase
+    :returns: Nothing
     """         
     for url in original_obj.get_url_list():
         if url and not url.get_privacy():
@@ -572,13 +671,13 @@ def copy_lds_ords(db, original_obj, clean_obj):
     Copies LDS ORDs from one object to another - excluding references to 
     private LDS ORDs.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have LDS ORDs
-    @type original_obj: LdsOrdBase
-    @param clean_obj: Object that will have only non-private LDS ORDs
-    @type original_obj: LdsOrdBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have LDS ORDs
+    :type original_obj: LdsOrdBase
+    :param clean_obj: Object that will have only non-private LDS ORDs
+    :type original_obj: LdsOrdBase
+    :returns: Nothing
     """         
     for lds_ord in original_obj.get_lds_ord_list():
         if lds_ord and not lds_ord.get_privacy():
@@ -589,13 +688,13 @@ def copy_addresses(db, original_obj, clean_obj):
     Copies addresses from one object to another - excluding references to 
     private addresses.
 
-    @param db: GRAMPS database to which the references belongs
-    @type db: DbBase
-    @param original_obj: Object that may have addresses
-    @type original_obj: AddressBase
-    @param clean_obj: Object that will have only non-private addresses
-    @type original_obj: AddressBase
-    @returns: Nothing
+    :param db: Gramps database to which the references belongs
+    :type db: DbBase
+    :param original_obj: Object that may have addresses
+    :type original_obj: AddressBase
+    :param clean_obj: Object that will have only non-private addresses
+    :type original_obj: AddressBase
+    :returns: Nothing
     """         
     for address in original_obj.get_address_list():
         if address and not address.get_privacy():
@@ -607,13 +706,13 @@ def sanitize_lds_ord(db, lds_ord):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the LdsOrd object belongs
-    @type db: DbBase
-    @param name: source LdsOrd object that will be copied with
-    privacy records removed
-    @type name: LdsOrd
-    @returns: 'cleansed' LdsOrd object
-    @rtype: LdsOrd
+    :param db: Gramps database to which the LdsOrd object belongs
+    :type db: DbBase
+    :param name: source LdsOrd object that will be copied with
+                 privacy records removed
+    :type name: LdsOrd
+    :returns: 'cleansed' LdsOrd object
+    :rtype: LdsOrd
     """
     new_lds_ord = LdsOrd()
     new_lds_ord.set_type(lds_ord.get_type())
@@ -643,13 +742,13 @@ def sanitize_address(db, address):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param name: source Address object that will be copied with
-    privacy records removed
-    @type name: Address
-    @returns: 'cleansed' Address object
-    @rtype: Address
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param name: source Address object that will be copied with
+                 privacy records removed
+    :type name: Address
+    :returns: 'cleansed' Address object
+    :rtype: Address
     """
     new_address = Address()
     
@@ -674,13 +773,13 @@ def sanitize_name(db, name):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param name: source Name object that will be copied with
-    privacy records removed
-    @type name: Name
-    @returns: 'cleansed' Name object
-    @rtype: Name
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param name: source Name object that will be copied with
+                 privacy records removed
+    :type name: Name
+    :returns: 'cleansed' Name object
+    :rtype: Name
     """
     new_name = Name()
     new_name.set_group_as(name.get_group_as())
@@ -707,13 +806,13 @@ def sanitize_media_ref(db, media_ref):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the MediaRef object belongs
-    @type db: DbBase
-    @param source_ref: source MediaRef object that will be copied with
-    privacy records removed
-    @type source_ref: MediaRef
-    @returns: 'cleansed' MediaRef object
-    @rtype: MediaRef
+    :param db: Gramps database to which the MediaRef object belongs
+    :type db: DbBase
+    :param source_ref: source MediaRef object that will be copied with
+                       privacy records removed
+    :type source_ref: MediaRef
+    :returns: 'cleansed' MediaRef object
+    :rtype: MediaRef
     """
     new_ref = MediaRef()
     new_ref.set_rectangle(media_ref.get_rectangle())
@@ -731,23 +830,23 @@ def sanitize_citation(db, citation):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param citation: source Citation object that will be copied with
-    privacy records removed
-    @type citation: Citation
-    @returns: 'cleansed' Citation object
-    @rtype: Citation
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param citation: source Citation object that will be copied with
+                     privacy records removed
+    :type citation: Citation
+    :returns: 'cleansed' Citation object
+    :rtype: Citation
     """
     new_citation = Citation()
     new_citation.set_date_object(citation.get_date_object())
     new_citation.set_page(citation.get_page())
     new_citation.set_confidence_level(citation.get_confidence_level())
     new_citation.set_reference_handle(citation.get_reference_handle())
-    new_citation.set_data_map(citation.get_data_map())
     new_citation.set_gramps_id(citation.get_gramps_id())
     new_citation.set_handle(citation.get_handle())
     new_citation.set_change_time(citation.get_change_time())
+    copy_srcattributes(db, citation, new_citation)
     copy_notes(db, citation, new_citation)
     copy_media_ref_list(db, citation, new_citation)
     
@@ -759,13 +858,13 @@ def sanitize_event_ref(db, event_ref):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param event_ref: source EventRef object that will be copied with
-    privacy records removed
-    @type event_ref: EventRef
-    @returns: 'cleansed' EventRef object
-    @rtype: EventRef
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param event_ref: source EventRef object that will be copied with
+                      privacy records removed
+    :type event_ref: EventRef
+    :returns: 'cleansed' EventRef object
+    :rtype: EventRef
     """
     new_ref = EventRef()
     
@@ -782,13 +881,13 @@ def sanitize_person(db, person):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param person: source Person object that will be copied with
-    privacy records removed
-    @type person: Person
-    @returns: 'cleansed' Person object
-    @rtype: Person
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param person: source Person object that will be copied with
+                   privacy records removed
+    :type person: Person
+    :returns: 'cleansed' Person object
+    :rtype: Person
     """
     new_person = Person()
 
@@ -875,13 +974,13 @@ def sanitize_source(db, source):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param source: source Source object that will be copied with
-    privacy records removed
-    @type source: Source
-    @returns: 'cleansed' Source object
-    @rtype: Source
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param source: source Source object that will be copied with
+                   privacy records removed
+    :type source: Source
+    :returns: 'cleansed' Source object
+    :rtype: Source
     """
     new_source = Source()
     
@@ -892,7 +991,6 @@ def sanitize_source(db, source):
     new_source.set_gramps_id(source.get_gramps_id())
     new_source.set_handle(source.get_handle())
     new_source.set_change_time(source.get_change_time())
-    new_source.set_data_map(source.get_data_map())
     
     for repo_ref in source.get_reporef_list():
         if repo_ref and not repo_ref.get_privacy():
@@ -901,6 +999,7 @@ def sanitize_source(db, source):
             if repo and not repo.get_privacy():
                 new_source.add_repo_reference(RepoRef(repo_ref))
 
+    copy_srcattributes(db, source, new_source)
     copy_media_ref_list(db, source, new_source)
     copy_notes(db, source, new_source)
     
@@ -912,13 +1011,13 @@ def sanitize_media(db, media):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param media: source Media object that will be copied with
-    privacy records removed
-    @type media: MediaObject
-    @returns: 'cleansed' Media object
-    @rtype: MediaObject
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param media: source Media object that will be copied with
+                  privacy records removed
+    :type media: MediaObject
+    :returns: 'cleansed' Media object
+    :rtype: MediaObject
     """
     new_media = MediaObject()
     
@@ -943,13 +1042,13 @@ def sanitize_place(db, place):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param place: source Place object that will be copied with
-    privacy records removed
-    @type place: Place
-    @returns: 'cleansed' Place object
-    @rtype: Place
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param place: source Place object that will be copied with
+                  privacy records removed
+    :type place: Place
+    :returns: 'cleansed' Place object
+    :rtype: Place
     """
     new_place = Place()
     
@@ -959,8 +1058,11 @@ def sanitize_place(db, place):
     new_place.set_change_time(place.get_change_time())
     new_place.set_longitude(place.get_longitude())
     new_place.set_latitude(place.get_latitude())
-    new_place.set_main_location(place.get_main_location())
     new_place.set_alternate_locations(place.get_alternate_locations())
+    new_place.set_name(place.get_name())
+    new_place.set_type(place.get_type())
+    new_place.set_code(place.get_code())
+    new_place.set_placeref_list(place.get_placeref_list())
 
     copy_citation_ref_list(db, place, new_place)
     copy_notes(db, place, new_place)
@@ -975,13 +1077,13 @@ def sanitize_event(db, event):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param event: source Event object that will be copied with
-    privacy records removed
-    @type event: Event
-    @returns: 'cleansed' Event object
-    @rtype: Event
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param event: source Event object that will be copied with
+                  privacy records removed
+    :type event: Event
+    :returns: 'cleansed' Event object
+    :rtype: Event
     """
     new_event = Event()
     
@@ -1010,13 +1112,13 @@ def sanitize_family(db, family):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param family: source Family object that will be copied with
-    privacy records removed
-    @type family: Family
-    @returns: 'cleansed' Family object
-    @rtype: Family
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param family: source Family object that will be copied with
+                   privacy records removed
+    :type family: Family
+    :returns: 'cleansed' Family object
+    :rtype: Family
     """
     new_family = Family()
     
@@ -1078,13 +1180,13 @@ def sanitize_repository(db, repository):
     instance. The returned instance has all private records
     removed from it.
     
-    @param db: GRAMPS database to which the Person object belongs
-    @type db: DbBase
-    @param repository: source Repository object that will be copied with
-    privacy records removed
-    @type repository: Repository
-    @returns: 'cleansed' Repository object
-    @rtype: Repository
+    :param db: Gramps database to which the Person object belongs
+    :type db: DbBase
+    :param repository: source Repository object that will be copied with
+                       privacy records removed
+    :type repository: Repository
+    :returns: 'cleansed' Repository object
+    :rtype: Repository
     """
     new_repository = Repository()
     
