@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -27,10 +27,7 @@ Provide soundex calculation
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-import sys
 import unicodedata
-if sys.version_info[0] < 3:
-    import string
 
 #-------------------------------------------------------------------------
 #
@@ -38,14 +35,8 @@ if sys.version_info[0] < 3:
 #
 #-------------------------------------------------------------------------
 IGNORE = "HW~!@#$%^&*()_+=-`[]\|;:'/?.,<>\" \t\f\v"
-if sys.version_info[0] < 3:
-    TABLE  = string.maketrans('ABCDEFGIJKLMNOPQRSTUVXYZ',
-                              '012301202245501262301202')
-else:
-    TABLE  = bytes.maketrans(b'ABCDEFGIJKLMNOPQRSTUVXYZ',
-                             b'012301202245501262301202')
-
-from .constfunc import conv_to_unicode_direct
+TABLE  = bytes.maketrans(b'ABCDEFGIJKLMNOPQRSTUVXYZ',
+                         b'012301202245501262301202')
 
 #-------------------------------------------------------------------------
 #
@@ -56,17 +47,12 @@ def soundex(strval):
     "Return the soundex value to a string argument."
 
     strval = unicodedata.normalize('NFKD', 
-        conv_to_unicode_direct(strval.upper().strip())).encode('ASCII', 'ignore')
+        str(strval.upper().strip())).encode('ASCII', 'ignore')
     if not strval:
         return "Z000"
-    if sys.version_info[0] < 3:
-        strval = strval.encode('iso-8859-1') # Really?
-        str2 = strval[0]
-        strval = strval.translate(TABLE, IGNORE)
-    else:
-        strval = strval.decode('ASCII', 'ignore')
-        str2 = strval[0]
-        strval = strval.translate(TABLE)
+    strval = strval.decode('ASCII', 'ignore')
+    str2 = strval[0]
+    strval = strval.translate(TABLE)
     if not strval:
         return "Z000"
     prev = strval[0]
