@@ -25,8 +25,6 @@
 # python modules
 #
 #------------------------------------------------------------------------
-# If you enable unicode_literals, some stuff needs fixing for win+py2, see #7162
-#from __future__ import print_function, unicode_literals
 import gettext
 import sys
 import os
@@ -65,6 +63,7 @@ if HAVE_ICU:
 # when a new translation is added.  Note the dummy _(): That's just to
 # get xgettext to include the string in gramps.pot; actual translation
 # is done in _get_language_string() below.
+# (The gramps officially-supported language list is ALL_LINGUAS in setup.py)
 _ = lambda x: x
 _LOCALE_NAMES = {
     'ar': ('Arabic_Saudi Arabia', '1256', _("Arabic")),
@@ -101,12 +100,14 @@ _LOCALE_NAMES = {
     'sk': ('Slovak_Slovakia', '1250', _("Slovak"),),
     'sl': ('Slovenian_Slovenia', '1250', _("Slovenian")),
     'sq': ('Albanian_Albania', '1250', _("Albanian")),
-    'sr': ('Serbian (Cyrillic)_Serbia', '1251', _("Serbian")),
+    'sr': ('Serbian(Cyrillic)_Serbia and Montenegro', '1251', _("Serbian")),
     'sv': ('Swedish_Sweden', '1252', _("Swedish")),
     'tr': ('Turkish_Turkey', '1254', _("Turkish")),
     'uk': ('Ukrainian_Ukraine', '1251', _("Ukrainian")),
     'vi': ('Vietnamese_Viet Nam', '1258', _("Vietnamese")),
-    'zh_CN': ('Chinese_China', '936', _("Chinese Simplified")),
+    'zh_CN': ('Chinese_China', '936', _("Chinese (Simplified)")),
+    'zh_HK': ('Chinese_Hong Kong', '950', _("Chinese (Hong Kong)")),
+    'zh_TW': ('Chinese_Taiwan', '950', _("Chinese (Traditional)")),
     }
 
 def _check_mswin_locale(locale):
@@ -208,7 +209,7 @@ class GrampsLocale(object):
                 self.lang = loc[0]
                 self.encoding = loc[1]
             else:
-                (lang, loc) = _check_mswin_locale(lang)
+                (lang, loc) = _check_mswin_locale(locale.getdefaultlocale()[0])
                 if lang:
                     self.lang = lang
                     self.encoding = loc[1]
@@ -421,24 +422,6 @@ class GrampsLocale(object):
             self.encoding = (locale.getpreferredencoding()
                              or sys.getdefaultencoding())
         LOG.debug("Setting encoding to %s", self.encoding)
-#Ensure that output is encoded correctly to stdout and stderr. This is
-#much less cumbersome and error-prone than encoding individual outputs
-#and better handles the differences between Python 2 and Python 3:
-        try:
-            _encoding = sys.stdout.encoding or sys.getdefaultencoding()
-        except:
-            _encoding = "UTF-8"
-        if sys.version_info[0] < 3:
-            sys.stdout = codecs.getwriter(_encoding)(sys.stdout,
-                                                     'backslashreplace')
-            sys.stderr = codecs.getwriter(_encoding)(sys.stderr,
-                                                     'backslashreplace')
-        else:
-            sys.stdout = codecs.getwriter(_encoding)(sys.stdout.detach(),
-                                                     'backslashreplace')
-            sys.stderr = codecs.getwriter(_encoding)(sys.stderr.detach(),
-                                                     'backslashreplace')
-
 
         # Make sure that self.lang and self.language are reflected
         # back into the environment for Gtk to use when its
@@ -852,6 +835,8 @@ class GrampsLocale(object):
             return _("the source")
         elif objclass == "filter":
             return _("the filter")
+        elif objclass == "citation":
+            return _("the citation")
         else:
             return _("See details")
 
@@ -864,9 +849,7 @@ class GrampsLocale(object):
             #ICU can digest strings and unicode
             return self.collator.getCollationKey(string).getByteArray()
         else:
-            if sys.version_info[0] < 3 and isinstance(string, unicode):
-                string = string.encode("utf-8", "replace")
-            if sys.version_info[0] >= 3 and isinstance(string, bytes):
+            if isinstance(string, bytes):
                 string = string.decode("utf-8", "replace")
             try:
                 key = locale.strxfrm(string)
@@ -953,13 +936,7 @@ class GrampsLocale(object):
 # Translations Classes
 #
 #-------------------------------------------------------------------------
-if sys.version_info < (3,0):
-    _LexemeBaseStr = unicode 
-    _isstring = lambda s: isinstance(s, basestring)
-else:
-    _LexemeBaseStr = str
-    _isstring = lambda s: isinstance(s, str)
-class Lexeme(_LexemeBaseStr):
+class Lexeme(str):
     r"""
     Created with :meth:`~GrampsTranslations.lexgettext`
 
@@ -1056,12 +1033,12 @@ class Lexeme(_LexemeBaseStr):
     """
 
     def __new__(cls, iterable, *args, **kwargs):
-        if _isstring(iterable):
-            newobj = _LexemeBaseStr.__new__(cls, iterable, *args, **kwargs)
+        if isinstance(iterable, str):
+            newobj = str.__new__(cls, iterable, *args, **kwargs)
         else:
             od = collections.OrderedDict(iterable)
             l = list(od.values()) or [""]
-            newobj = _LexemeBaseStr.__new__(cls, l[0], *args, **kwargs) 
+            newobj = str.__new__(cls, l[0], *args, **kwargs) 
             newobj._forms = od
         return newobj
 
@@ -1102,10 +1079,7 @@ class GrampsTranslations(gettext.GNUTranslations):
         # and that's not what we want.
         if len(msgid.strip()) == 0:
             return msgid
-        if sys.version_info[0] < 3:
-            return gettext.GNUTranslations.ugettext(self, msgid)
-        else:
-            return gettext.GNUTranslations.gettext(self, msgid)
+        return gettext.GNUTranslations.gettext(self, msgid)
 
     def ngettext(self, singular, plural, num):
         """
@@ -1123,12 +1097,7 @@ class GrampsTranslations(gettext.GNUTranslations):
         :returns: Translation or the original.
         :rtype: unicode
         """
-        if sys.version_info[0] < 3:
-            return gettext.GNUTranslations.ungettext(self, singular,
-                                                     plural, num)
-        else:
-            return gettext.GNUTranslations.ngettext(self, singular,
-                                                    plural, num)
+        return gettext.GNUTranslations.ngettext(self, singular, plural, num)
 
     def sgettext(self, msgid, sep='|'):
         """
