@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
-from __future__ import unicode_literals
 import sys
 import io
 import os
@@ -49,7 +48,6 @@ class ResourcePath(object):
     def __init__(self):
         if self.initialized:
             return
-
         resource_file = os.path.join(os.path.abspath(os.path.dirname(
             conv_to_unicode(__file__))), 'resource-path')
         installed = os.path.exists(resource_file)
@@ -76,8 +74,13 @@ class ResourcePath(object):
                 LOG.error("Resource Path %s is invalid", resource_path)
                 sys.exit(1)
         else:
-            LOG.error("Unable to determine resource path")
-            sys.exit(1)
+            # Let's try to run from source without env['GRAMPS_RESOURCES']:
+            resource_path = os.path.join(os.path.abspath(os.path.dirname(
+                conv_to_unicode(__file__))), '..', "..", "..")
+            test_path = os.path.join("data", "authors.xml")
+            if (not os.path.exists(os.path.join(resource_path, test_path))):
+                LOG.error("Unable to determine resource path")
+                sys.exit(1)
 
         if installed:
             self.locale_dir = os.path.join(resource_path, 'locale')
