@@ -24,11 +24,7 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
-import sys
-if sys.version_info[0] < 3:
-    import cPickle as pickle
-else:
-    import pickle
+import pickle
 import os
 from xml.sax.saxutils import escape
 from time import strftime as strftime
@@ -52,8 +48,10 @@ from gramps.gen.const import IMAGE_DIR, URL_MANUAL_PAGE, GRAMPS_LOCALE as glocal
 from gramps.gen.config import config
 from gramps.gen.lib import NoteType
 from gramps.gen.datehandler import get_date
+from gramps.gen.display.place import displayer as place_displayer
 from .display import display_help
 from .managedwindow import ManagedWindow
+from gramps.gen.errors import WindowActiveError
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.constfunc import mac
@@ -61,7 +59,6 @@ from .glade import Glade
 from .ddtargets import DdTargets
 from .makefilter import make_filter
 from .utils import is_right_click
-from gramps.gen.constfunc import cuni, STRTYPE
 
 #-------------------------------------------------------------------------
 #
@@ -77,29 +74,28 @@ WIKI_HELP_SEC = _('manual|Using_the_Clipboard')
 #
 #-------------------------------------------------------------------------
 
-_stock_image = os.path.join(IMAGE_DIR,'stock_link.png')
-LINK_PIC = GdkPixbuf.Pixbuf.new_from_file(_stock_image)
+theme = Gtk.IconTheme.get_default()
+LINK_PIC = theme.load_icon('stock_link', 16, 0)
 ICONS = {}
-for (name, file) in (
-    ("media", "gramps-media.png"),
-    ("note", "gramps-notes.png"),
-    ("person", "gramps-person.png"),
-    ("place", "gramps-place.png"),
-    ('address', 'gramps-address.png'),
-    ('attribute', 'gramps-attribute.png'),
-    ('event', 'gramps-event.png'),
-    ('family', 'gramps-family.png'),
-    ('location', 'geo-place-link.png'),
-    ('media', 'gramps-media.png'),
-    ('name', 'geo-show-person.png'),
-    ('repository', 'gramps-repository.png'),
-    ('source', 'gramps-source.png'),
-    ('citation', 'gramps-citation.png'),
-    ('text', 'gramps-font.png'),
-    ('url', 'gramps-geo.png'),
+for (name, icon) in (
+    ("media", "gramps-media"),
+    ("note", "gramps-notes"),
+    ("person", "gramps-person"),
+    ("place", "gramps-place"),
+    ('address', 'gramps-address'),
+    ('attribute', 'gramps-attribute'),
+    ('event', 'gramps-event'),
+    ('family', 'gramps-family'),
+    ('location', 'geo-place-link'),
+    ('media', 'gramps-media'),
+    ('name', 'geo-show-person'),
+    ('repository', 'gramps-repository'),
+    ('source', 'gramps-source'),
+    ('citation', 'gramps-citation'),
+    ('text', 'gramps-font'),
+    ('url', 'gramps-geo'),
     ):
-    _image = os.path.join(IMAGE_DIR, '16x16', file)
-    ICONS[name] = GdkPixbuf.Pixbuf.new_from_file(_image) 
+    ICONS[name] = theme.load_icon(icon, 16, 0)
 
 #-------------------------------------------------------------------------
 #
@@ -177,7 +173,7 @@ def model_contains(model, data):
 #
 #-------------------------------------------------------------------------
 class ClipWrapper(object):
-    UNAVAILABLE_ICON = Gtk.STOCK_DIALOG_ERROR
+    UNAVAILABLE_ICON = 'dialog-error'
 
     def __init__(self, dbstate, obj):
         dbstate.connect('database-changed', self.database_changed)
@@ -227,15 +223,12 @@ class ClipWrapper(object):
                 }
             return pickle.dumps(data)
         else:
-            if sys.version_info[0] < 3:
-                return str(self._obj)
+            if isinstance(self._obj, bytes):
+                return self._obj
             else:
-                if isinstance(self._obj, bytes):
-                    return self._obj
-                else:
-                    ## don't know if this happens in Gramps, theoretically possible
-                    asuni = str(self._obj)
-                    return asuni.encode('utf-8')
+                ## don't know if this happens in Gramps, theoretically possible
+                asuni = str(self._obj)
+                return asuni.encode('utf-8')
 
     def is_valid(self):
         return True
@@ -380,7 +373,7 @@ class ClipPlace(ClipHandleWrapper):
             value = self._db.get_place_from_handle(self._handle)
             if value:
                 self._title = value.gramps_id
-                self._value = value.get_title() 
+                self._value = place_displayer.display(self._db, value)
 
     def is_valid(self):
         data = pickle.loads(self._obj)
@@ -409,7 +402,7 @@ class ClipNote(ClipHandleWrapper):
             note = value.get().replace('\n', ' ')
             #String must be unicode for truncation to work for non
             #ascii characters
-            note = cuni(note)
+            note = str(note)
             if len(note) > 80:
                 self._value = note[:80]+"..."
             else:
@@ -515,7 +508,7 @@ class ClipCitation(ClipHandleWrapper):
                     text = " ".join(srctxtlist[0].get().split())
                 #String must be unicode for truncation to work for non
                 #ascii characters
-                    text = cuni(text)
+                    text = str(text)
                     if len(text) > 60:
                         text =  text[:60]+"..."
                 self._value = _("Volume/Page: %(pag)s -- %(sourcetext)s") % {
@@ -583,7 +576,7 @@ class ClipPlaceRef(ClipObjWrapper):
             base = self._db.get_place_from_handle(self._obj.ref)
             if base:
                 self._title = base.gramps_id
-                self._value = str(base.get_name())
+                self._value = place_displayer.display(self._db, base)
 
 class ClipName(ClipObjWrapper):
 
@@ -601,6 +594,22 @@ class ClipName(ClipObjWrapper):
             self._title = str(self._obj.get_type())
             self._value = self._obj.get_name()
 
+class ClipPlaceName(ClipObjWrapper):
+
+    DROP_TARGETS = [DdTargets.PLACENAME]
+    DRAG_TARGET  = DdTargets.PLACENAME
+    ICON         = ICONS['name']
+
+    def __init__(self, dbstate, obj):
+        super(ClipPlaceName, self).__init__(dbstate, obj)
+        self._type  = _("Place Name")
+        self.refresh()
+
+    def refresh(self):
+        if self._obj:
+            self._title = get_date(self._obj)
+            self._value = self._obj.get_value()
+
 class ClipSurname(ClipObjWrapper):
 
     DROP_TARGETS = [DdTargets.SURNAME]
@@ -626,12 +635,18 @@ class ClipText(ClipWrapper):
     def __init__(self, dbstate, obj):
         super(ClipText, self).__init__(dbstate, obj)
         self._type  = _("Text")
-        self._pickle = self._obj
+        if isinstance(self._obj, bytes):
+            self._pickle = str(self._obj, "utf-8")
+        else:
+            self._pickle = self._obj
         self.refresh()
 
     def refresh(self):
         self._title = _("Text")
-        self._value = self._obj
+        if isinstance(self._obj, bytes):
+            self._value = str(self._obj, "utf-8")
+        else:
+            self._value = self._obj
 
 class ClipMediaObj(ClipHandleWrapper):
 
@@ -1106,6 +1121,7 @@ class ClipboardListView(object):
         self.register_wrapper_class(ClipAttribute)
         self.register_wrapper_class(ClipFamilyAttribute)
         self.register_wrapper_class(ClipName)
+        self.register_wrapper_class(ClipPlaceName)
         self.register_wrapper_class(ClipRepositoryLink)
         self.register_wrapper_class(ClipMediaObj)
         self.register_wrapper_class(ClipMediaRef)
@@ -1129,9 +1145,9 @@ class ClipboardListView(object):
     
     def object_pixbuf(self, column, cell, model, node, user_data=None):
         o = model.get_value(node, 1)
-        if o._dbid != self.dbstate.db.get_dbid():
-            if isinstance(o.__class__.UNAVAILABLE_ICON, STRTYPE):
-                cell.set_property('stock-id', 
+        if o._dbid is not None and o._dbid != self.dbstate.db.get_dbid():
+            if isinstance(o.__class__.UNAVAILABLE_ICON, str):
+                cell.set_property('icon-name',
                                   o.__class__.UNAVAILABLE_ICON)
             else:
                 cell.set_property('pixbuf', 
@@ -1242,7 +1258,7 @@ class ClipboardListView(object):
                 dragtype = pickle.loads(sel_data)[0]
             except pickle.UnpicklingError as msg :
                 # not a pickled object, probably text
-                if isinstance(sel_data, STRTYPE):
+                if isinstance(sel_data, str):
                     dragtype = DdTargets.TEXT.drag_type
             if dragtype in self._target_type_to_wrapper_class_map:
                 possible_wrappers = [dragtype]
@@ -1378,7 +1394,7 @@ class ClipboardWindow(ManagedWindow):
         mtv = MultiTreeView(self.dbstate, self.uistate, _("Clipboard"))
         scrolledwindow = self.top.get_object('scrolledwindow86')
         scrolledwindow.remove(objectlist)
-        scrolledwindow.add_with_viewport(mtv)
+        scrolledwindow.add(mtv)
         self.object_list = ClipboardListView(self.dbstate, mtv)
         self.object_list.get_selection().connect('changed',
                                                  self.set_clear_btn_sensitivity)
@@ -1461,6 +1477,7 @@ class MultiTreeView(Gtk.TreeView):
         Gtk.TreeView.__init__(self)
         self.connect('button_press_event', self.on_button_press)
         self.connect('button_release_event', self.on_button_release)
+        self.connect('grab_broken_event', self.on_grab_broken)
         self.connect('key_press_event', self.key_press_event)
         self.defer_select = False
 
@@ -1491,13 +1508,14 @@ class MultiTreeView(Gtk.TreeView):
             o = None
             if node:
                 o = store.get_value(node, 1)
-            popup = Gtk.Menu()
+            self.newmenu = Gtk.Menu()
+            popup = self.newmenu
             # ---------------------------
             if o:
                 objclass, handle = o._objclass, o._handle
             else:
                 objclass, handle = None, None
-            if objclass in ['Person', 'Event', 'Media', 'Source',
+            if objclass in ['Person', 'Event', 'Media', 'Source', 'Citation',
                             'Repository', 'Family', 'Note', 'Place']:
                 menu_item = Gtk.MenuItem(label=_("the object|See %s details") % glocale.trans_objclass(objclass))
                 menu_item.connect("activate", 
@@ -1561,9 +1579,15 @@ class MultiTreeView(Gtk.TreeView):
             
         self.defer_select=False
 
+    def on_grab_broken(self, widget, event):
+        # re-enable selection
+        self.get_selection().set_select_function(lambda *ignore: True, None)
+        self.defer_select=False
+
     def edit_obj(self, objclass, handle):
         from .editors import (EditPerson, EditEvent, EditFamily, EditSource,
-                                 EditPlace, EditRepository, EditNote, EditMedia)
+                              EditPlace, EditRepository, EditNote, EditMedia,
+                              EditCitation)
         if objclass == 'Person':
             person = self.dbstate.db.get_person_from_handle(handle)
             if person:
@@ -1628,6 +1652,15 @@ class MultiTreeView(Gtk.TreeView):
                               self.uistate, [], ref)
                 except WindowActiveError:
                     pass
+        elif objclass == 'Citation':
+            ref = self.dbstate.db.get_citation_from_handle(handle)
+            if ref:
+                try:
+                    EditCitation(self.dbstate,
+                               self.uistate, [], ref)
+                except WindowActiveError:
+                    pass
+
 
 def short(val,size=60):
     if len(val) > size:
@@ -1635,12 +1668,8 @@ def short(val,size=60):
     else:
         return val
 
-def place_title(db,event):
-    pid = event.get_place_handle()
-    if pid:
-        return db.get_place_from_handle(pid).get_title()
-    else:
-        return ''
+def place_title(db, event):
+    return place_displayer.display_event(db, event)
 
 def gen_del_obj(func, t):
     return lambda l : func(l, t)
