@@ -30,8 +30,6 @@ mechanism for the user to edit address information.
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 import pickle
 
 #-------------------------------------------------------------------------
@@ -47,6 +45,8 @@ from gi.repository import Gtk
 # gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.sgettext
 from .editsecondary import EditSecondary
 from gramps.gen.lib import NoteType
 from gramps.gen.errors import WindowActiveError
@@ -56,6 +56,7 @@ from gi.repository import Gdk
 from .displaytabs import CitationEmbedList, NoteTab
 from ..widgets import MonitoredDataType, PrivacyButton
 from gramps.gen.display.name import displayer as name_displayer
+from gramps.gen.const import URL_MANUAL_SECT1
 
 #-------------------------------------------------------------------------
 #
@@ -63,6 +64,9 @@ from gramps.gen.display.name import displayer as name_displayer
 #
 #-------------------------------------------------------------------------
 
+WIKI_HELP_PAGE = URL_MANUAL_SECT1
+WIKI_HELP_SEC = _('manual|Child_Reference_Editor')
+
 _RETURN = Gdk.keyval_from_name("Return")
 _KP_ENTER = Gdk.keyval_from_name("KP_Enter")
 _LEFT_BUTTON = 1
@@ -139,12 +143,13 @@ class EditChildRef(EditSecondary):
             self.db.readonly)
 
     def _connect_signals(self):
-        self.define_help_button(self.top.get_object('help'))
         self.define_cancel_button(self.top.get_object('cancel'))
         self.define_ok_button(self.ok_button, self.save)
         self.edit_button.connect('button-press-event', self.edit_child)
         self.edit_button.connect('key-press-event', self.edit_child)
-    
+        self.define_help_button(self.top.get_object('help'),
+                WIKI_HELP_PAGE, WIKI_HELP_SEC)
+
     def _connect_db_signals(self):
         """
         Connect any signals that need to be connected. 
