@@ -79,7 +79,10 @@ from gramps.gen.datehandler import displayer
 # Constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = WIKI_HELP_PAGE = '%s_-_Filters' % URL_MANUAL_PAGE
+WIKI_HELP_PAGE = '%s_-_Filters' % URL_MANUAL_PAGE
+WIKI_HELP_SEC = _('manual|Add_Rule_dialog')
+WIKI_HELP_SEC2 = _('manual|Define_Filter_dialog')
+WIKI_HELP_SEC3 = _('manual|Custom_Filters')
 
 # dictionary mapping FILTER_TYPE of views to Filter window name
 _TITLES = {
@@ -149,7 +152,8 @@ class MyInteger(Gtk.SpinButton):
 
     def __init__(self, min, max):
         GObject.GObject.__init__(self)
-        self.set_adjustment(Gtk.Adjustment(min, min, max, 1))
+        self.set_adjustment(Gtk.Adjustment(value=min, lower=min, upper=max,
+                                           step_increment=1))
         self.show()
 
     def get_text(self):
@@ -551,7 +555,8 @@ class EditRule(ManagedWindow):
                     elif v == _('Surname origin type:'):
                         additional = self.db.get_origin_types()
                     elif v == _('Place type:'):
-                        additional = self.db.get_place_types()
+                        additional = sorted(self.db.get_place_types(),
+                                            key=lambda s: s.lower())
                     t = MySelect(_name2typeclass[v], additional)
                 elif v == _('Inclusive:'):
                     t = MyBoolean(_('Include original person'))
@@ -714,7 +719,8 @@ class EditRule(ManagedWindow):
         """
         Display the relevant portion of Gramps manual.
         """
-        display_help()
+        display_help(webpage=WIKI_HELP_PAGE,
+                                   section=WIKI_HELP_SEC)
 
     def close_window(self, obj):
         self.close()
@@ -827,7 +833,8 @@ class EditFilter(ManagedWindow):
 
     def on_help_clicked(self, obj):
         """Display the relevant portion of Gramps manual"""
-        display_help(webpage=WIKI_HELP_PAGE)
+        display_help(webpage=WIKI_HELP_PAGE,
+                                   section=WIKI_HELP_SEC2)
 
     def close_window(self, obj):
         self.close()
@@ -1085,7 +1092,8 @@ class FilterEditor(ManagedWindow):
         
     def help_clicked(self, obj):
         """Display the relevant portion of Gramps manual"""
-        display_help()
+        display_help(webpage=WIKI_HELP_PAGE,
+                                   section=WIKI_HELP_SEC3)
 
     def filter_select_row(self, obj):
         store, node = self.clist.get_selected()
