@@ -47,7 +47,6 @@ from gi.repository import Gtk
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import GLADE_DIR, GRAMPS_LOCALE as glocale
-from gramps.gen.constfunc import STRTYPE, uni_to_gui
 
 #------------------------------------------------------------------------
 #
@@ -122,7 +121,7 @@ class Glade(Gtk.Builder):
         
         # try to build Gtk objects from glade file.  Let exceptions happen
         
-        self.add_from_file(uni_to_gui(path))
+        self.add_from_file(path)
         self.__dirname, self.__filename = os.path.split(path)
         
         # try to find the toplevel widget
@@ -203,7 +202,7 @@ class Glade(Gtk.Builder):
             if not toplevel:
                 raise ValueError("Top level object required")
                 
-        if isinstance(toplevel, STRTYPE):
+        if isinstance(toplevel, str):
             toplevel = self.get_object(toplevel)
             
         # Simple Breadth-First Search
