@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -30,7 +30,7 @@ Provide merge capabilities for families.
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.display.name import displayer as name_displayer
-from gramps.gen.const import URL_MANUAL_PAGE
+from gramps.gen.const import URL_MANUAL_SECT3
 from ..display import display_help
 from gramps.gen.errors import MergeError
 from ..dialog import ErrorDialog
@@ -42,8 +42,7 @@ from gramps.gen.merge import MergePersonQuery, MergeFamilyQuery
 # Gramps constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = '%s_-_Entering_and_Editing_Data:_Detailed_-_part_3' % \
-    URL_MANUAL_PAGE
+WIKI_HELP_PAGE = URL_MANUAL_SECT3
 WIKI_HELP_SEC = _('manual|Merge_Families')
 _GLADE_FILE = 'mergefamily.glade'
 
@@ -148,8 +147,9 @@ class MergeFamily(ManagedWindow):
         rbutton1 = self.get_widget("handle_btn1")
         rbutton_label1 = self.get_widget("label_handle_btn1")
         rbutton_label2 = self.get_widget("label_handle_btn2")
-        rbutton_label1.set_label("%s and %s [%s]" %(father1, mother1, gramps1))
-        rbutton_label2.set_label("%s and %s [%s]" %(father2, mother2, gramps2))
+        add = _("and")
+        rbutton_label1.set_label("%s %s %s [%s]" %(father1, add, mother1, gramps1))
+        rbutton_label2.set_label("%s %s %s [%s]" %(father2, add, mother2, gramps2))
         rbutton1.connect("toggled", self.on_handle1_toggled)
 
         self.connect_button("family_help", self.cb_help)
