@@ -67,7 +67,10 @@ class User(user.User):
         :type steps: int
         :returns: none
         """
-        self._progress = ProgressMeter(title)
+        if self.uistate:
+            self._progress = ProgressMeter(title, parent=self.uistate.window)
+        else:
+            self._progress = ProgressMeter(title)
         if steps > 0:
             self._progress.set_pass(message, steps, ProgressMeter.MODE_FRACTION)
         else:
@@ -106,7 +109,8 @@ class User(user.User):
         :returns: the user's answer to the question
         :rtype: bool
         """
-        dialog = QuestionDialog2(title, message, accept_label, reject_label, parent)
+        dialog = QuestionDialog2(title, message, accept_label, reject_label,
+                                 parent)
         return dialog.run()
     
     def warn(self, title, warning=""):
@@ -119,7 +123,10 @@ class User(user.User):
         :type warning: str
         :returns: none
         """
-        WarningDialog(title, warning)
+        if self.uistate:
+            WarningDialog(title, warning, parent=self.uistate.window)
+        else:
+            WarningDialog(title, warning)
     
     def notify_error(self, title, error=""):
         """
@@ -133,6 +140,8 @@ class User(user.User):
         """
         if self.error_function:
             self.error_function(title, error)
+        elif self.uistate:
+            ErrorDialog(title, error, parent=self.uistate.window)
         else:
             ErrorDialog(title, error)
 
@@ -144,7 +153,10 @@ class User(user.User):
         :type error: str
         :returns: none
         """
-        DBErrorDialog(error)
+        if self.uistate:
+            DBErrorDialog(error, parent=self.uistate.window)
+        else:
+            DBErrorDialog(error)
 
     def info(self, msg1, infotext, parent=None, monospaced=False):
         """
