@@ -28,8 +28,6 @@ GrampletView interface.
 # Python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function, unicode_literals
-
 from gi.repository import GObject
 from gi.repository import Gdk
 from gi.repository import Gtk
@@ -37,11 +35,7 @@ from gi.repository import Pango
 import time
 import os
 import io
-import sys
-if sys.version_info[0] < 3:
-    import ConfigParser as configparser
-else:
-    import configparser
+import configparser
 
 import logging
 
@@ -63,7 +57,6 @@ from ..display import display_help, display_url
 from ..glade import Glade
 from ..pluginmanager import GuiPluginManager
 from .undoablebuffer import UndoableBuffer
-from gramps.gen.constfunc import cuni
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 
@@ -242,11 +235,11 @@ class GrampletWindow(ManagedWindow):
                                              self.title)
         self.set_window(Gtk.Dialog("", gramplet.uistate.window,
                                    Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                   (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)),
+                                   (_('_Close'), Gtk.ResponseType.CLOSE)),
                         None, self.title)
         self.window.set_size_request(gramplet.detached_width,
                                      gramplet.detached_height)
-        self.window.add_button(Gtk.STOCK_HELP, Gtk.ResponseType.HELP)
+        self.window.add_button(_('_Help'), Gtk.ResponseType.HELP)
         # add gramplet:
         if self.gramplet.pui:
             self.gramplet.pui.active = True
@@ -267,7 +260,7 @@ class GrampletWindow(ManagedWindow):
         """
         Callback for taking care of button clicks.
         """
-        if response in [Gtk.ResponseType.CLOSE, Gtk.STOCK_CLOSE]:
+        if response == Gtk.ResponseType.CLOSE:
             self.close()
         elif response == Gtk.ResponseType.HELP:
             # translated name:
@@ -565,19 +558,21 @@ class GuiGramplet(object):
         # END WORKAROUND
         if len(self.pui.option_order) == 0: return
         frame = Gtk.Frame()
-        topbox = Gtk.VBox(homogeneous=False)
-        hbox = Gtk.HBox(homogeneous=False, spacing=5)
-        labels = Gtk.VBox(homogeneous=True)
-        options = Gtk.VBox(homogeneous=True)
+        topbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        hbox = Gtk.Box(spacing=5)
+        labels = Gtk.Box(orientation=Gtk.Orientation.VERTICAL,
+                         homogeneous=True)
+        options = Gtk.Box(orientation=Gtk.Orientation.VERTICAL,
+                          homogeneous=True)
         hbox.pack_start(labels, False, True, 0)
         hbox.pack_start(options, True, True, 0)
         topbox.pack_start(hbox, False, False, 0)
         for item in self.pui.option_order:
             label = Gtk.Label(label=item + ":")
-            label.set_alignment(1.0, 0.5)
+            label.set_halign(Gtk.Align.END)
             labels.pack_start(label, True, True, 0)
             options.pack_start(self.pui.option_dict[item][0], True, True, 0) # widget
-        save_button = Gtk.Button(stock=Gtk.STOCK_SAVE)
+        save_button = Gtk.Button.new_with_mnemonic(_('_Save'))
         topbox.pack_end(save_button, False, False, 0)
         save_button.connect('clicked', self.pui.save_update_options)
         frame.add(topbox)
@@ -734,7 +729,7 @@ class GuiGramplet(object):
 
     def set_has_data(self, value):
         if isinstance(self.pane, Gtk.Notebook):
-            if self.pane.get_tab_label(self):
+            if self.pane.page_num(self) != -1:
                 label = self.pane.get_tab_label(self)
                 label.set_has_data(value)
 
@@ -780,11 +775,11 @@ class GridGramplet(GuiGramplet):
         self.gvstate.connect('clicked', self.change_state)
         self.gvproperties = self.xml.get_object('gvproperties')
         self.gvproperties.connect('clicked', self.set_properties)
-        self.xml.get_object('gvcloseimage').set_from_stock(Gtk.STOCK_CLOSE,
+        self.xml.get_object('gvcloseimage').set_from_icon_name('window-close',
                                                            Gtk.IconSize.MENU)
-        self.xml.get_object('gvstateimage').set_from_stock(Gtk.STOCK_REMOVE,
+        self.xml.get_object('gvstateimage').set_from_icon_name('list-remove',
                                                            Gtk.IconSize.MENU)
-        self.xml.get_object('gvpropertiesimage').set_from_stock(Gtk.STOCK_PROPERTIES,
+        self.xml.get_object('gvpropertiesimage').set_from_icon_name('document-properties',
                                                                 Gtk.IconSize.MENU)
 
         # source:
@@ -869,14 +864,14 @@ class GridGramplet(GuiGramplet):
         self.gstate = state
         if state == "minimized":
             self.scrolledwindow.hide()
-            self.xml.get_object('gvstateimage').set_from_stock(Gtk.STOCK_ADD,
+            self.xml.get_object('gvstateimage').set_from_icon_name('list-add',
                                                             Gtk.IconSize.MENU)
             column = self.mainframe.get_parent() # column
             expand, fill, padding, pack = column.query_child_packing(self.mainframe)
             column.set_child_packing(self.mainframe, False, fill, padding, pack)
         else:
             self.scrolledwindow.show()
-            self.xml.get_object('gvstateimage').set_from_stock(Gtk.STOCK_REMOVE,
+            self.xml.get_object('gvstateimage').set_from_icon_name('list-remove',
                                                             Gtk.IconSize.MENU)
             column = self.mainframe.get_parent() # column
             expand, fill, padding, pack = column.query_child_packing(self.mainframe)
@@ -998,9 +993,9 @@ class GrampletPane(Gtk.ScrolledWindow):
         self.set_tooltip_text(msg)
         self.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         self.eventb = Gtk.EventBox()
-        self.hbox = Gtk.HBox(homogeneous=True)
+        self.hbox = Gtk.Box(homogeneous=True)
         self.eventb.add(self.hbox)
-        self.add_with_viewport(self.eventb)
+        self.add(self.eventb)
         self.set_kinetic_scrolling(True)
         self.set_capture_button_press(True)
         # Set up drag and drop
@@ -1019,7 +1014,7 @@ class GrampletPane(Gtk.ScrolledWindow):
         # Create the columns:
         self.columns = []
         for i in range(self.column_count):
-            self.columns.append(Gtk.VBox())
+            self.columns.append(Gtk.Box(orientation=Gtk.Orientation.VERTICAL))
             self.hbox.pack_start(self.columns[-1], True, True, 0)
         # Load the gramplets
         self.gramplet_map = {} # title->gramplet
@@ -1147,7 +1142,7 @@ class GrampletPane(Gtk.ScrolledWindow):
         if filename and os.path.exists(filename):
             cp = configparser.ConfigParser()
             try:
-                cp.read(filename)
+                cp.read(filename, encoding='utf-8')
             except Exception as err:
                 LOG.warning("Failed to load gramplets from %s because %s",
                             filename, str(err))
@@ -1336,7 +1331,7 @@ class GrampletPane(Gtk.ScrolledWindow):
         self.column_count = num
         self.columns = []
         for i in range(self.column_count):
-            self.columns.append(Gtk.VBox())
+            self.columns.append(Gtk.Box(orientation=Gtk.Orientation.VERTICAL))
             self.columns[-1].show()
             self.hbox.pack_start(self.columns[-1], True, True, 0)
         # place the gramplets back in the new columns
@@ -1519,23 +1514,23 @@ class GrampletPane(Gtk.ScrolledWindow):
         """
         Function that builds the widget in the configuration dialog
         """
-        table = Gtk.Table(n_rows=3, n_columns=2)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
 
         self._config.register('Gramplet View Options.column_count',
                               int,
                               self.get_columns, # pane
                               self.set_columns) # pane
 
-        configdialog.add_pos_int_entry(table, 
+        configdialog.add_pos_int_entry(grid, 
                  _('Number of Columns'), 
                  0, 
                 'Gramplet View Options.column_count',
                 self._config.set,
                 config=self._config)
-        return _('Gramplet Layout'), table
+        return _('Gramplet Layout'), grid
  
     def build_panel(self, gramplet):
         self._config.register("%s.title" % gramplet.title, 
@@ -1552,39 +1547,39 @@ class GrampletPane(Gtk.ScrolledWindow):
                               bool, gramplet.get_expand, gramplet.set_expand)
         def gramplet_panel(configdialog):
             configdialog.window.set_size_request(600, -1)
-            table = Gtk.Table(n_rows=3, n_columns=2)
-            table.set_border_width(12)
-            table.set_col_spacings(6)
-            table.set_row_spacings(6)
+            grid = Gtk.Grid()
+            grid.set_border_width(12)
+            grid.set_column_spacing(6)
+            grid.set_row_spacing(6)
             # Title:
-            configdialog.add_entry(table, 
+            configdialog.add_entry(grid, 
                 _('Title'), 
                 0, 
                 "%s.title" % gramplet.title,
                 self._config.set,
                 config=self._config)
             # Expand to max height
-            configdialog.add_checkbox(table, 
+            configdialog.add_checkbox(grid, 
                 _("Use maximum height available"), 
                 1, 
                 "%s.expand" % gramplet.title, 
                 config=self._config)
             # Height
-            configdialog.add_pos_int_entry(table, 
+            configdialog.add_pos_int_entry(grid, 
                 _('Height if not maximized'), 
                 2, 
                 "%s.height" % gramplet.title,
                 self._config.set,
                 config=self._config)
             # Detached height
-            configdialog.add_pos_int_entry(table, 
+            configdialog.add_pos_int_entry(grid, 
                 _('Detached width'), 
                 3, 
                 "%s.detached_width" % gramplet.title,
                 self._config.set,
                 config=self._config)
             # Detached width
-            configdialog.add_pos_int_entry(table, 
+            configdialog.add_pos_int_entry(grid, 
                 _('Detached height'), 
                 4, 
                 "%s.detached_height" % gramplet.title,
@@ -1593,8 +1588,8 @@ class GrampletPane(Gtk.ScrolledWindow):
             # Options:
             options = gramplet.make_gui_options()
             if options:
-                table.attach(options, 1, 4, 5, 6, yoptions=0)
-            return gramplet.title, table
+                grid.attach(options, 1, 5, 3, 1)
+            return gramplet.title, grid
         return gramplet_panel
 
 class Configuration(object):
