@@ -60,9 +60,10 @@ from .toolcomboentry import ToolComboEntry
 from .springseparator import SpringSeparatorAction
 from ..spell import Spell
 from ..display import display_url
-from ..utils import SystemFonts, rgb_to_hex, hex_to_color, color_to_hex
+from ..utils import SystemFonts, rgb_to_hex
 from gramps.gen.config import config
 from gramps.gen.constfunc import has_display
+from ..actiongroup import ActionGroup
 
 #-------------------------------------------------------------------------
 #
@@ -201,17 +202,6 @@ class StyledTextEditor(Gtk.TextView):
 
         self._connect_signals()
 
-        # we want to disable the unicode menu in the popup
-        settings = Gtk.Settings.get_default()
-        # 'gtk-show-unicode-menu' is deprecated since Gtk-3.10
-        if Gtk.get_minor_version() < 10:
-            try:
-                self.show_unicode = settings.get_property('gtk-show-unicode-menu')
-                settings.set_property('gtk-show-unicode-menu', False)
-            except:
-                #GTK wants to deprecate show-unicode-menu, this prepares for this
-                self.show_unicode = False
-        
         # variable to not copy to clipboard on double/triple click
         self.selclick = False
 
@@ -248,21 +238,6 @@ class StyledTextEditor(Gtk.TextView):
             window.set_cursor(REGULAR_CURSOR)
             self.url_match = None
         
-    def on_unrealize(self, widget):
-        """
-        Signal handler.
-        
-        Set the default Gtk settings back before leaving.
-        """
-        # 'gtk-show-unicode-menu' is deprecated since Gtk-3.10
-        if Gtk.get_minor_version() < 10:
-            try:
-                settings = Gtk.Settings.get_default()
-                settings.set_property('gtk-show-unicode-menu', self.show_unicode)
-            except:
-                #GTK wants to deprecate show-unicode-menu, this prepares for this
-                pass
-        
     def on_key_press_event(self, widget, event):
         """Signal handler.
         
@@ -406,13 +381,18 @@ class StyledTextEditor(Gtk.TextView):
             
             if flavor == MAIL:
                 open_menu = Gtk.MenuItem(label=_('_Send Mail To...'))
+                open_menu.set_use_underline(True)
                 copy_menu = Gtk.MenuItem(label=_('Copy _E-mail Address'))
+                copy_menu.set_use_underline(True)
             else:
                 open_menu = Gtk.MenuItem(label=_('_Open Link'))
+                open_menu.set_use_underline(True)
                 copy_menu = Gtk.MenuItem(label=_('Copy _Link Address'))
+                copy_menu.set_use_underline(True)
 
             if flavor == LINK:
                 edit_menu = Gtk.MenuItem(label=_('_Edit Link'))
+                edit_menu.set_use_underline(True)
                 edit_menu.connect('activate', self._edit_url_cb, 
                                   self.url_match[-1], # tag
                                   )
@@ -459,7 +439,6 @@ class StyledTextEditor(Gtk.TextView):
         self.connect('button-press-event', self.on_button_press_event)
         self.connect('button-release-event', self.on_button_release_event)
         self.connect('populate-popup', self.on_populate_popup)
-        self.connect('unrealize', self.on_unrealize)
         
     def _create_toolbar(self):
         """
@@ -471,12 +450,12 @@ class StyledTextEditor(Gtk.TextView):
         # define the actions...
         # ...first the toggle actions, which have a ToggleToolButton as proxy
         format_toggle_actions = [
-            (str(StyledTextTagType.ITALIC), Gtk.STOCK_ITALIC, None, None,
+            (str(StyledTextTagType.ITALIC), 'format-text-italic', None, None,
              _('Italic'), self._on_toggle_action_activate),
-            (str(StyledTextTagType.BOLD), Gtk.STOCK_BOLD, None, None,
+            (str(StyledTextTagType.BOLD), 'format-text-bold', None, None,
              _('Bold'), self._on_toggle_action_activate),
-            (str(StyledTextTagType.UNDERLINE), Gtk.STOCK_UNDERLINE, None, None,
-             _('Underline'), self._on_toggle_action_activate),
+            (str(StyledTextTagType.UNDERLINE), 'format-text-underline', None,
+            None, _('Underline'), self._on_toggle_action_activate),
         ]
         
         self.toggle_actions = [action[0] for action in format_toggle_actions]
@@ -485,11 +464,11 @@ class StyledTextEditor(Gtk.TextView):
         format_actions = [
             (str(StyledTextTagType.FONTCOLOR), 'gramps-font-color', None, None,
              _('Font Color'), self._on_action_activate),
-            (str(StyledTextTagType.HIGHLIGHT), 'gramps-font-bgcolor', None, None,
-             _('Background Color'), self._on_action_activate),
-            (str(StyledTextTagType.LINK), Gtk.STOCK_JUMP_TO, None, None,
+            (str(StyledTextTagType.HIGHLIGHT), 'gramps-font-bgcolor', None,
+            None, _('Background Color'), self._on_action_activate),
+            (str(StyledTextTagType.LINK), 'go-jump', None, None,
              _('Link'), self._on_link_activate),
-            ('clear', Gtk.STOCK_CLEAR, None, None,
+            ('clear', 'edit-clear', None, None,
              _('Clear Markup'), self._format_clear_cb),
         ]
         
@@ -528,14 +507,15 @@ class StyledTextEditor(Gtk.TextView):
         }
 
         # create the action group and insert all the actions
-        self.action_group = Gtk.ActionGroup(name='Format')
+        self.action_group = ActionGroup(name='Format')
         self.action_group.add_toggle_actions(format_toggle_actions)
         self.undo_action = Gtk.Action(name="Undo", label=_('Undo'),
-                                        tooltip=_('Undo'), 
-                                        stock_id=Gtk.STOCK_UNDO)
+                                      tooltip=_('Undo'))
+        self.undo_action.set_icon_name('edit-undo')
         self.undo_action.connect('activate', self.undo)
-        self.redo_action = Gtk.Action.new("Redo", _('Redo'), _('Redo'),
-                                        Gtk.STOCK_REDO)
+        self.redo_action = Gtk.Action.new(name="Redo", label=_('Redo'),
+                                          tooltip=_('Redo'))
+        self.redo_action.set_icon_name('edit-redo')
         self.redo_action.connect('activate', self.redo)
         self.action_group.add_action(self.undo_action)
         self.action_group.add_action(self.redo_action)
@@ -657,21 +637,23 @@ class StyledTextEditor(Gtk.TextView):
         current_value = self.textbuffer.get_style_at_cursor(style)
 
         if style == StyledTextTagType.FONTCOLOR:
-            color_dialog = Gtk.ColorSelectionDialog(_("Select font color"))
+            color_dialog = Gtk.ColorChooserDialog(_("Select font color"))
         elif style == StyledTextTagType.HIGHLIGHT:
-            color_dialog = Gtk.ColorSelectionDialog(_("Select "
-                                                         "background color"))
+            color_dialog = Gtk.ColorChooserDialog(_("Select background color"))
         else:
             _LOG.debug("unknown style: '%d'" % style)
             return
 
-        color_selection = color_dialog.get_color_selection()
         if current_value:
-            color_selection.set_current_color(hex_to_color(current_value))
+            rgba = Gdk.RGBA()
+            rgba.parse(current_value)
+            color_dialog.set_rgba(rgba)
 
         response = color_dialog.run()
-        color = color_selection.get_current_color()
-        value = color_to_hex(color)
+        rgba = color_dialog.get_rgba()
+        value = '#%02x%02x%02x' % (int(rgba.red * 255),
+                                   int(rgba.green * 255),
+                                   int(rgba.blue * 255))
         color_dialog.destroy()
         
         if response == Gtk.ResponseType.OK:
