@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 __all__ = ["MaskedEntry", "ValidatableMaskedEntry"]
@@ -52,20 +52,8 @@ from gi.repository import Pango
 #
 #-------------------------------------------------------------------------
 from gramps.gen.errors import MaskError, ValidationError, WindowActiveError
-from gramps.gen.constfunc import cuni, UNITYPE
 from .undoableentry import UndoableEntry
 
-#-------------------------------------------------------------------------
-#
-# Constants
-#
-#-------------------------------------------------------------------------
-# STOCK_INFO was added only in Gtk 2.8
-try:
-    INFO_ICON = Gtk.STOCK_INFO
-except AttributeError:
-    INFO_ICON = Gtk.STOCK_DIALOG_INFO
-
 #============================================================================
 #
 # MaskedEntry and ValidatableMaskedEntry copied and merged from the Kiwi
@@ -139,12 +127,8 @@ class FadeOut(GObject.GObject):
         ##_LOG.debug('_start_merging: Starting')
         generator = self._merge_colors(self._start_color, 
                                   Gdk.color_parse(self.ERROR_COLOR))
-        if sys.version_info[0] < 3:
-            func = generator.next
-        else:
-            func = generator.__next__
         self._background_timeout_id = (
-            GLib.timeout_add(FadeOut.MERGE_COLORS_DELAY, func))
+            GLib.timeout_add(FadeOut.MERGE_COLORS_DELAY, generator.__next__))
         self._countdown_timeout_id = -1
 
     def start(self, color):
@@ -204,20 +188,12 @@ INPUT_FORMATS = {
 #  ? - Ascii letter, optional
 #  C - Alpha, optional
 
-if sys.version_info[0] < 3:
-    INPUT_CHAR_MAP = {
-        INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters, 
-        INPUT_ALPHA:            unicode.isalpha, 
-        INPUT_ALPHANUMERIC:     unicode.isalnum, 
-        INPUT_DIGIT:            unicode.isdigit, 
-        }
-else:
-    INPUT_CHAR_MAP = {
-        INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters, 
-        INPUT_ALPHA:            str.isalpha, 
-        INPUT_ALPHANUMERIC:     str.isalnum, 
-        INPUT_DIGIT:            str.isdigit, 
-        }
+INPUT_CHAR_MAP = {
+    INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters, 
+    INPUT_ALPHA:            str.isalpha, 
+    INPUT_ALPHANUMERIC:     str.isalnum, 
+    INPUT_DIGIT:            str.isdigit, 
+    }
 
 (COL_TEXT, 
  COL_OBJECT) = list(range(2))
@@ -321,7 +297,7 @@ class MaskedEntry(UndoableEntry):
         :param mask: the mask to set
         """
         if not mask:
-            self.modify_font(Pango.FontDescription("sans"))
+            self.override_font(Pango.FontDescription("sans"))
             self._mask = mask
             return
 
@@ -330,7 +306,7 @@ class MaskedEntry(UndoableEntry):
         self._mask_fields = []
         self._current_field = -1
 
-        mask = cuni(mask)
+        mask = str(mask)
         input_length = len(mask)
         lenght = 0
         pos = 0
@@ -351,7 +327,7 @@ class MaskedEntry(UndoableEntry):
             pos += 1
 
         self._mask_fields.append((field_begin, field_end))
-        self.modify_font(Pango.FontDescription("monospace"))
+        self.override_font(Pango.FontDescription("monospace"))
 
         self._really_delete_text(0, -1)
         self._insert_mask(0, input_length)
@@ -389,7 +365,7 @@ class MaskedEntry(UndoableEntry):
 
         fields = []
 
-        text = cuni(self.get_text())
+        text = str(self.get_text())
         for start, end in self._mask_fields:
             fields.append(text[start:end].strip())
 
@@ -414,7 +390,7 @@ class MaskedEntry(UndoableEntry):
         for validator in self._mask_validators[start:end]:
             if isinstance(validator, int):
                 s += ' '
-            elif isinstance(validator, UNITYPE):
+            elif isinstance(validator, str):
                 s += validator
             else:
                 raise AssertionError
@@ -605,7 +581,7 @@ class MaskedEntry(UndoableEntry):
         if isinstance(validator, int):
             if not INPUT_CHAR_MAP[validator](text):
                 return False
-        if isinstance(validator, UNITYPE):
+        if isinstance(validator, str):
             if validator == text:
                 return True
             return False
@@ -810,7 +786,7 @@ class MaskedEntry(UndoableEntry):
         if not self._mask:
             UndoableEntry._on_insert_text(self, editable, new, length, position)
             return
-        new = cuni(new)
+        new = str(new)
         pos = self.get_position()
 
         self.stop_emission('insert-text')
@@ -1034,8 +1010,8 @@ class MaskedEntry(UndoableEntry):
     def set_pixbuf(self, pixbuf):
         self.set_icon_from_pixbuf(Gtk.EntryIconPosition.SECONDARY, pixbuf)
 
-    def set_stock(self, stock_name):
-        self.set_icon_from_stock(Gtk.EntryIconPosition.SECONDARY, stock_name)
+    def set_stock(self, icon_name):
+        self.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, icon_name)
 
     def update_background(self, color, unset=False):
         maxvalcol = 65535.
@@ -1113,8 +1089,8 @@ class MaskedEntry(UndoableEntry):
 #number = (int, float, long)
 
 VALIDATION_ICON_WIDTH = 16
-MANDATORY_ICON = INFO_ICON
-ERROR_ICON = Gtk.STOCK_STOP
+MANDATORY_ICON = 'dialog-information'
+ERROR_ICON = 'process-stop'
 
 class ValidatableMaskedEntry(MaskedEntry):
     """
@@ -1140,16 +1116,21 @@ class ValidatableMaskedEntry(MaskedEntry):
         'changed': 'override', 
     }
 
+    if GLib.MINOR_VERSION < 42:
+        __gparam = GObject.PARAM_READWRITE
+    else:
+        __gparam = GObject.ParamFlags.READWRITE
+
     __gproperties__ = {
         'data-type': (GObject.TYPE_PYOBJECT, 
                        'Data Type of the widget', 
                        'Type object', 
-                       GObject.PARAM_READWRITE), 
+                       __gparam), 
         'mandatory': (GObject.TYPE_BOOLEAN, 
                       'Mandatory', 
                       'Mandatory', 
                       False, 
-                      GObject.PARAM_READWRITE), 
+                      __gparam),
     }
                             
     # FIXME put the data type support back
@@ -1423,7 +1404,7 @@ def main(args):
         Gtk.main_quit()
     win.connect('delete-event', cb)
 
-    vbox = Gtk.VBox()
+    vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
     win.add(vbox)
     
     label = Gtk.Label(label='Pre-filled entry validated against the given list:')
