@@ -25,22 +25,16 @@
 
 "Export to CSV Spreadsheet."
 
-
-from __future__ import unicode_literals
 #-------------------------------------------------------------------------
 #
 # Standard Python Modules
 #
 #-------------------------------------------------------------------------
 import os
-import sys
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 import csv
-if sys.version_info[0] < 3:
-    from cStringIO import StringIO
-else:
-    from io import StringIO
+from io import StringIO
 import codecs
 
 #------------------------------------------------------------------------
@@ -62,6 +56,7 @@ from gramps.gen.lib.eventroletype import EventRoleType
 from gramps.gui.plug.export import WriterOptionBox
 from gramps.gen.utils.string import gender as gender_map
 from gramps.gen.datehandler import get_date
+from gramps.gen.display.place import displayer as _pd
 from gramps.gui.glade import Glade
 
 #-------------------------------------------------------------------------
@@ -156,15 +151,8 @@ class UnicodeWriter(object):
         self.encoder = codecs.getencoder(encoding)
 
     def writerow(self, row):
-        if sys.version_info[0] < 3:
-            self.writer.writerow([s.encode('utf-8') for s in row])
-            # Fetch UTF-8 output from the queue ...
-            data = self.queue.getvalue()
-            data = data.decode('utf-8')
-        else:
-            self.writer.writerow(row)
-            data = self.queue.getvalue()
-            #in python3, StringIO self.queue returns unicode!
+        self.writer.writerow(row)
+        data = self.queue.getvalue()
         #data now contains the csv data in unicode
         # ... and reencode it into the target encoding
         data, length = self.encoder(data)
@@ -193,13 +181,16 @@ class CSVWriterOptionBox(WriterOptionBox):
     """
     def __init__(self, person, dbstate, uistate):
         WriterOptionBox.__init__(self, person, dbstate, uistate)
+        ## TODO: add place filter selection
         self.include_individuals = 1
         self.include_marriages = 1
         self.include_children = 1
+        self.include_places = 1
         self.translate_headers = 1
         self.include_individuals_check = None
         self.include_marriages_check = None
         self.include_children_check = None
+        self.include_places_check = None
         self.translate_headers_check = None
 
     def get_option_box(self):
@@ -209,16 +200,19 @@ class CSVWriterOptionBox(WriterOptionBox):
         self.include_individuals_check = Gtk.CheckButton(label=_("Include people"))
         self.include_marriages_check = Gtk.CheckButton(label=_("Include marriages"))
         self.include_children_check = Gtk.CheckButton(label=_("Include children"))
+        self.include_places_check = Gtk.CheckButton(label=_("Include places"))
         self.translate_headers_check = Gtk.CheckButton(label=_("Translate headers"))
 
         self.include_individuals_check.set_active(1) 
         self.include_marriages_check.set_active(1) 
         self.include_children_check.set_active(1) 
+        self.include_places_check.set_active(1) 
         self.translate_headers_check.set_active(1) 
 
         option_box.pack_start(self.include_individuals_check, False, True, 0)
         option_box.pack_start(self.include_marriages_check, False, True, 0)
         option_box.pack_start(self.include_children_check, False, True, 0)
+        option_box.pack_start(self.include_places_check, False, True, 0)
         option_box.pack_start(self.translate_headers_check, False, True, 0)
 
         return option_box
@@ -229,6 +223,7 @@ class CSVWriterOptionBox(WriterOptionBox):
             self.include_individuals = self.include_individuals_check.get_active()
             self.include_marriages = self.include_marriages_check.get_active()
             self.include_children = self.include_children_check.get_active()
+            self.include_places = self.include_places_check.get_active()
             self.translate_headers = self.translate_headers_check.get_active()
 
 #-------------------------------------------------------------------------
@@ -249,6 +244,7 @@ class CSVWriter(object):
 
         self.plist = {}
         self.flist = {}
+        self.place_list = {}
         
         self.persons_details_done = []
         self.persons_notes_done = []
@@ -258,6 +254,7 @@ class CSVWriter(object):
             self.include_individuals = 1
             self.include_marriages = 1
             self.include_children = 1
+            self.include_places = 1
             self.translate_headers = 1
         else:
             self.option_box.parse_options()
@@ -266,9 +263,24 @@ class CSVWriter(object):
             self.include_individuals = self.option_box.include_individuals
             self.include_marriages = self.option_box.include_marriages
             self.include_children = self.option_box.include_children
+            self.include_places = self.option_box.include_places
             self.translate_headers = self.option_box.translate_headers
             
         self.plist = [x for x in self.db.iter_person_handles()]
+
+        # make place list so that dependencies are first:
+        self.place_list = []
+        place_list = [x for x in self.db.iter_place_handles()]
+        while place_list:
+            handle = place_list[0]
+            place = self.db.get_place_from_handle(handle)
+            if place:
+                if all([(x.ref in self.place_list) for x in place.placeref_list]):
+                    self.place_list.append(place_list.pop(0))
+                else: # put at the back of the line:
+                    place_list.append(place_list.pop(0))
+            else:
+                place_list.pop(0)
         # get the families for which these people are spouses:
         self.flist = {}
         for key in self.plist:
@@ -325,9 +337,12 @@ class CSVWriter(object):
             self.total += len(self.flist)
         if self.include_children:
             self.total += len(self.flist)
+        if self.include_places:
+            self.total += len(self.place_list)
         ######################## 
         LOG.debug("Possible people to export: %s", len(self.plist))
         LOG.debug("Possible families to export: %s", len(self.flist))
+        LOG.debug("Possible places to export: %s", len(self.place_list))
         ########################### sort:
         sortorder = []
         dropped_surnames = set()
@@ -413,8 +428,7 @@ class CSVWriter(object):
                             birthdate = self.format_date( birth)
                             place_handle = birth.get_place_handle()
                             if place_handle:
-                                place = self.db.get_place_from_handle(place_handle)
-                                birthplace = place.get_title()
+                                birthplace = _pd.display_event(self.db, birth)
                             birthsource = get_primary_source_title(self.db, birth)
                     # Baptism:
                     baptismdate = ""
@@ -428,8 +442,7 @@ class CSVWriter(object):
                             baptismdate = self.format_date( baptism)
                             place_handle = baptism.get_place_handle()
                             if place_handle:
-                                place = self.db.get_place_from_handle(place_handle)
-                                baptismplace = place.get_title()
+                                baptismplace = _pd.display_event(self.db, baptism)
                             baptismsource = get_primary_source_title(self.db, baptism)
                     # Death:
                     deathdate = ""
@@ -442,8 +455,7 @@ class CSVWriter(object):
                             deathdate = self.format_date( death)
                             place_handle = death.get_place_handle()
                             if place_handle:
-                                place = self.db.get_place_from_handle(place_handle)
-                                deathplace = place.get_title()
+                                deathplace = _pd.display_event(self.db, death)
                             deathsource = get_primary_source_title(self.db, death)
                     # Burial:
                     burialdate = ""
@@ -457,8 +469,7 @@ class CSVWriter(object):
                             burialdate = self.format_date( burial)
                             place_handle = burial.get_place_handle()
                             if place_handle:
-                                place = self.db.get_place_from_handle(place_handle)
-                                burialplace = place.get_title()
+                                burialplace = _pd.display_event(self.db, burial)
                             burialsource = get_primary_source_title(self.db, burial)
                     # Write it out:
                     self.write_csv(grampsid_ref, surname, first_name, callname,
@@ -518,8 +529,7 @@ class CSVWriter(object):
                             mdate = self.format_date( event)
                             place_handle = event.get_place_handle()
                             if place_handle:
-                                place = self.db.get_place_from_handle(place_handle)
-                                mplace = place.get_title()
+                                mplace = _pd.display_event(self.db, event)
                                 source = get_primary_source_title(self.db, event)
                     note = ''
                     self.write_csv(marriage_id, father_id, mother_id, mdate,
@@ -547,6 +557,43 @@ class CSVWriter(object):
                         self.write_csv(family_id, grampsid_ref)
                 self.update()
             self.writeln()
+        ########################### 
+        if self.include_places:
+            if self.translate_headers:
+                self.write_csv(_("Place"), _("Title"), _("Name"), 
+                               _("Type"), _("Latitude"), _("Longitude"), 
+                               _("Code"), _("Enclosed_by"), _("Date"))
+            else:
+                self.write_csv("Place", "Title", "Name", 
+                               "Type", "Latitude", "Longitude", 
+                               "Code", "Enclosed_by", "Date")
+            for key in self.place_list:
+                place = self.db.get_place_from_handle(key)
+                if place:
+                    place_id = place.gramps_id
+                    place_title = place.title
+                    place_name = place.name.value
+                    place_type = str(place.place_type)
+                    place_latitude = place.lat
+                    place_longitude = place.long
+                    place_code = place.code
+                    if place.placeref_list:
+                        for placeref in place.placeref_list:
+                            placeref_obj = self.db.get_place_from_handle(placeref.ref)
+                            placeref_date = ""
+                            if not placeref.date.is_empty():
+                                placeref_date = placeref.date
+                            placeref_id = ""
+                            if placeref_obj:
+                                placeref_id = "[%s]" % placeref_obj.gramps_id
+                            self.write_csv("[%s]" % place_id, place_title, place_name, place_type,
+                                           place_latitude, place_longitude, place_code, placeref_id,
+                                           placeref_date)
+                    else:
+                        self.write_csv("[%s]" % place_id, place_title, place_name, place_type,
+                                       place_latitude, place_longitude, place_code, "",
+                                       "")
+            self.writeln()
         self.g.close()
         return True 
     
