@@ -32,7 +32,7 @@ Gramps' XML file format.
 
 #-------------------------------------------------------------------------
 #
-# load standard python libraries
+# Standard python modules
 #
 #-------------------------------------------------------------------------
 import time
@@ -40,9 +40,6 @@ import shutil
 import os
 import codecs
 from xml.sax.saxutils import escape
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
-
 
 #------------------------------------------------------------------------
 #
@@ -54,17 +51,19 @@ LOG = logging.getLogger(".WriteXML")
 
 #-------------------------------------------------------------------------
 #
-# load Gramps libraries
+# Gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
+from gramps.gen.const import URL_HOMEPAGE
 from gramps.gen.lib import Date, Person
 from gramps.gen.updatecallback import UpdateCallback
 from gramps.gen.db.exceptions import DbWriteFailure
 from gramps.version import VERSION
-from gramps.gen.constfunc import win
+from gramps.gen.constfunc import win, conv_to_unicode
 from gramps.gui.plug.export import WriterOptionBox
 import gramps.plugins.lib.libgrampsxml as libgrampsxml
-from gramps.gen.constfunc import cuni, conv_to_unicode
 
 #-------------------------------------------------------------------------
 #
@@ -127,7 +126,7 @@ class GrampsXmlWriter(UpdateCallback):
         """
         if filename == '-':
             import sys
-            g = sys.stdout
+            g = sys.stdout.buffer
             self.compress = False
         else:
             base = os.path.dirname(filename)
@@ -140,6 +139,12 @@ class GrampsXmlWriter(UpdateCallback):
                             "Please make sure you have write access to the "
                                 "directory and try again."))
                     return 0
+            else:
+                raise DbWriteFailure(_('No directory'),
+                                     _('There is no directory %s.\n\n'
+                                       'Please select another directory '
+                                       'or create it.') % base )
+                return 0
                 
             if os.path.exists(filename):
                 if not os.access(filename, os.W_OK):
@@ -218,11 +223,11 @@ class GrampsXmlWriter(UpdateCallback):
         self.g.write('<?xml version="1.0" encoding="UTF-8"?>\n')
         self.g.write('<!DOCTYPE database '
                      'PUBLIC "-//Gramps//DTD Gramps XML %s//EN"\n'
-                     '"http://gramps-project.org/xml/%s/grampsxml.dtd">\n'
-                     % (libgrampsxml.GRAMPS_XML_VERSION, 
+                     '"%sxml/%s/grampsxml.dtd">\n'
+                     % (libgrampsxml.GRAMPS_XML_VERSION, URL_HOMEPAGE,
                         libgrampsxml.GRAMPS_XML_VERSION))
-        self.g.write('<database xmlns="http://gramps-project.org/xml/%s/">\n'
-                     % libgrampsxml.GRAMPS_XML_VERSION)
+        self.g.write('<database xmlns="%sxml/%s/">\n'
+                     % (URL_HOMEPAGE, libgrampsxml.GRAMPS_XML_VERSION))
         self.g.write("  <header>\n")
         self.g.write('    <created date="%04d-%02d-%02d\"' % date[:3])
         self.g.write(" version=\"" + self.version + "\"")
@@ -435,7 +440,7 @@ class GrampsXmlWriter(UpdateCallback):
         
     def fix(self,line):
         try:
-            l = cuni(line)
+            l = str(line)
         except:
             l = conv_to_unicode(str(line), errors='replace')
         l = l.strip().translate(strip_dict)
@@ -455,7 +460,7 @@ class GrampsXmlWriter(UpdateCallback):
         format = note.get_format()
         text = note.get_styledtext()
         styles = text.get_tags()
-        text = cuni(text)
+        text = str(text)
 
         self.g.write(' type="%s"' % ntype)
         if format != note.FLOWED:
@@ -726,6 +731,21 @@ class GrampsXmlWriter(UpdateCallback):
             self.write_date(date, index+1)
             self.g.write('%s</placeref>\n' % sp)
 
+    def dump_place_name(self, place_name, index=1):
+        sp = "  " * index
+        value = place_name.get_value()
+        date = place_name.get_date_object()
+        lang = place_name.get_language()
+        self.g.write('%s<pname value="%s"' % (sp, self.fix(value)))
+        if lang:
+            self.g.write(' lang="%s"' % self.fix(lang))
+        if date.is_empty():
+            self.g.write('/>\n')
+        else:
+            self.g.write('>\n')
+            self.write_date(date, index+1)
+            self.g.write('%s</pname>\n' % sp)
+
     def write_event(self,event,index=1):
         if not event:
             return
@@ -1191,9 +1211,7 @@ class GrampsXmlWriter(UpdateCallback):
 
     def write_place_obj(self, place, index=1):
         self.write_primary_tag("placeobj", place, index, close=False)
-        pname = self.fix(place.get_name())
         ptype = self.fix(place.get_type().xml_str())
-        self.g.write(' name="%s"' % pname)
         self.g.write(' type="%s"' % ptype)
         self.g.write('>\n')
 
@@ -1201,8 +1219,10 @@ class GrampsXmlWriter(UpdateCallback):
         code = self.fix(place.get_code())
         self.write_line_nofix("ptitle", title, index+1)
         self.write_line_nofix("code", code, index+1)
-        for name in place.get_alternative_names():
-            self.write_line("alt_name", name, index+1)
+
+        self.dump_place_name(place.get_name(), index+1)
+        for pname in place.get_alternative_names():
+            self.dump_place_name(pname, index+1)
 
         longitude = self.fix(place.get_longitude())
         lat = self.fix(place.get_latitude())
