@@ -24,13 +24,6 @@
 Base view for Place Views
 """
 
-#-------------------------------------------------------------------------
-#
-# Global modules
-#
-#-------------------------------------------------------------------------
-from __future__ import print_function
-
 #-------------------------------------------------------------------------
 #
 # GTK/Gnome modules
@@ -149,7 +142,7 @@ class PlaceBaseView(ListView):
                                 "Service (OpenstreetMap, Google Maps, ...)"),
                         self.gotomap,
                         _('Select a Map Service'))
-        self._add_action('GotoMap', Gtk.STOCK_JUMP_TO, 
+        self._add_action('GotoMap', 'go-jump',
                         _('_Look up with Map Service'),
                         callback=self.gotomap,
                         tip=_("Attempt to see this location with a Map "
@@ -179,7 +172,8 @@ class PlaceBaseView(ListView):
         ListView.change_page(self)
         #menutoolbutton has to be made and added in correct place on toolbar
         if not self.maptoolbtn:
-            self.maptoolbtn = Gtk.MenuToolButton.new_from_stock(Gtk.STOCK_JUMP_TO)
+            self.maptoolbtn = Gtk.MenuToolButton()
+            self.maptoolbtn.set_icon_name('go-jump')
             self.maptoolbtn.connect('clicked', self.gotomap)
             self.mmenu = self.__create_maps_menu_actions()
             self.maptoolbtn.set_menu(self.mmenu)
@@ -208,7 +202,7 @@ class PlaceBaseView(ListView):
         lbl.show()
         self.mapslistlabel.append(lbl)
         widget.set_label_widget(self.mapslistlabel[-1])
-        widget.set_stock_id(Gtk.STOCK_JUMP_TO)
+        widget.set_icon_name('go-jump')
         if self.drag_info():
             self.list.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK,
               [],
@@ -264,7 +258,7 @@ class PlaceBaseView(ListView):
         if not len(self.mapservicedata):
             msg = _("No map service is available.")
             msg2 = _("Check your installation.")
-            ErrorDialog(msg, msg2)
+            ErrorDialog(msg, msg2, parent=self.uistate.window)
             return
         
         place_handles = self.selected_handles()
@@ -275,7 +269,7 @@ class PlaceBaseView(ListView):
             msg2 = _("You need to select a place to be able to view it"
                      " on a map. Some Map Services might support multiple"
                      " selections.")
-            ErrorDialog(msg, msg2)
+            ErrorDialog(msg, msg2, parent=self.uistate.window)
             return
         
         #TODO: support for descriptions in some cases. For now, pass None
@@ -369,7 +363,7 @@ class PlaceBaseView(ListView):
                 msg = _("Cannot delete place.")
                 msg2 = _("This place is currently referenced by another place. "
                          "First remove the places it contains.")
-                ErrorDialog(msg, msg2)
+                ErrorDialog(msg, msg2, parent=self.uistate.window)
                 return
         self.remove_selected_objects()       
 
@@ -412,14 +406,14 @@ class PlaceBaseView(ListView):
             msg2 = _("Exactly two places must be selected to perform a merge. "
                      "A second place can be selected by holding down the "
                      "control key while clicking on the desired place.")
-            ErrorDialog(msg, msg2)
+            ErrorDialog(msg, msg2, parent=self.uistate.window)
         else:
             if (located_in(self.dbstate.db, mlist[0], mlist[1]) or
                 located_in(self.dbstate.db, mlist[1], mlist[0])):
                 msg = _("Cannot merge places.")
                 msg2 = _("Merging these places would create a cycle in the "
                          "place hierarchy.")
-                ErrorDialog(msg, msg2)
+                ErrorDialog(msg, msg2, parent=self.uistate.window)
             else:
                 MergePlace(self.dbstate, self.uistate, mlist[0], mlist[1],
                            self.merged)
