@@ -49,7 +49,7 @@ import cairo
 # Gramps Modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.lib import EventType, Place, PlaceType, PlaceRef
+from gramps.gen.lib import EventType, Place, PlaceType, PlaceRef, PlaceName
 from gramps.gen.display.name import displayer as _nd
 from gramps.gen.display.place import displayer as _pd
 from gramps.gui.views.navigationview import NavigationView
@@ -68,6 +68,7 @@ from .osmgps import OsmGps
 from .selectionlayer import SelectionLayer
 from .placeselection import PlaceSelection
 from .cairoprint import CairoPrintSave
+from .libkml import Kml
 
 #------------------------------------------------------------------------
 #
@@ -152,16 +153,11 @@ class GeoGraphyView(OsmGps, NavigationView):
         self.places_found = []
         self.select_fct = None
         self.geo_mainmap = None
-        path = os.path.join(IMAGE_DIR, "48x48",
-                            ('gramps-geo-mainmap' + '.png' ))
-        with open(path, 'rb') as fh: # this is to avoid bug with cairo 1.8.8
-            self.geo_mainmap = cairo.ImageSurface.create_from_png(fh)
-        #self.geo_mainmap = cairo.ImageSurface.create_from_png(path)
-        path = os.path.join(IMAGE_DIR, "48x48",
-                            ('gramps-geo-altmap' + '.png' ))
-        with open(path, 'rb') as fh: # this is to avoid bug with cairo 1.8.8
-            self.geo_altmap = cairo.ImageSurface.create_from_png(fh)
-        #self.geo_altmap = cairo.ImageSurface.create_from_png(path)
+        theme = Gtk.IconTheme.get_default()
+        self.geo_mainmap = theme.load_surface('gramps-geo-mainmap', 48, 1, 
+                                              None, 0)
+        self.geo_altmap = theme.load_surface('gramps-geo-altmap', 48, 1,
+                                             None, 0)
         if ( config.get('geography.map_service') in
             ( constants.OPENSTREETMAP,
               constants.MAPS_FOR_FREE,
@@ -175,13 +171,22 @@ class GeoGraphyView(OsmGps, NavigationView):
         for ident in ( EventType.BIRTH,
                     EventType.DEATH,
                     EventType.MARRIAGE ):
-            path = os.path.join(IMAGE_DIR, "48x48",
-                                (constants.ICONS.get(int(ident), default_image) + '.png' ))
-            with open(path, 'rb') as fh: # this is to avoid bug with cairo 1.8.8
-                self.geo_othermap[ident] = cairo.ImageSurface.create_from_png(fh)
-            #self.geo_othermap[ident] = cairo.ImageSurface.create_from_png(path)
+            icon = constants.ICONS.get(int(ident))
+            self.geo_othermap[ident] = theme.load_surface(icon, 48, 1, None, 0)
 
-    def add_bookmark(self, menu, handle):
+    def add_bookmark(self, menu):
+        mlist = self.selected_handles()
+        if mlist:
+            self.bookmarks.add(mlist[0])
+        else:
+            from gramps.gui.dialog import WarningDialog
+            WarningDialog(
+                _("Could Not Set a Bookmark"), 
+                _("A bookmark could not be set because "
+                  "no one was selected."))
+        
+
+    def add_bookmark_from_popup(self, menu, handle):
         if handle:
             self.uistate.set_active(handle, self.navigation_type())
             self.bookmarks.add(handle)
@@ -268,9 +273,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Associate the print button to the PrintView action.
         """
-        self._add_action('PrintView', Gtk.STOCK_PRINT, _("_Print..."), 
-                         accel="<PRIMARY>P", 
-                         tip=_("Print or save the Map"), 
+        self._add_action('PrintView', 'document-print', _("_Print..."),
+                         accel="<PRIMARY>P",
+                         tip=_("Print or save the Map"),
                          callback=self.printview)
 
     def config_connect(self):
@@ -338,6 +343,11 @@ class GeoGraphyView(OsmGps, NavigationView):
         add_item.show()
         menu.append(add_item)
 
+        add_item = Gtk.MenuItem(label=_("Add place from kml"))
+        add_item.connect("activate", self.add_place_from_kml, event, lat , lon)
+        add_item.show()
+        menu.append(add_item)
+
         add_item = Gtk.MenuItem(label=_("Center here"))
         add_item.connect("activate", self.set_center, event, lat , lon)
         add_item.show()
@@ -380,9 +390,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         clearmap.show()
         menu.append(clearmap)
         menu.show()
-        menu.popup(None, None,
-                   lambda menu, data: (event.get_root_coords()[0],
-                                       event.get_root_coords()[1], True),
+        menu.popup(None, None, None,
                    None, event.button, event.time)
         return 1
 
@@ -780,6 +788,26 @@ class GeoGraphyView(OsmGps, NavigationView):
                 mnam = _nd.display(mother) if mother else _("Unknown")
         return ( fnam, mnam )
 
+    #-------------------------------------------------------------------------
+    #
+    # KML functionalities
+    #
+    #-------------------------------------------------------------------------
+    def load_kml_files(self, obj):
+        """
+        obj can be an event, a person or a place
+        """
+        media_list = obj.get_media_list()
+        if media_list:
+            for media_ref in media_list:
+                object_handle = media_ref.get_reference_handle()
+                media_obj = self.dbstate.db.get_object_from_handle(object_handle)
+                path = media_obj.get_path()
+                name, extension = os.path.splitext(path)
+                if extension == ".kml":
+                    if os.path.isfile(path):
+                        self.kml_layer.add_kml(path)
+
     #-------------------------------------------------------------------------
     #
     # Printing functionalities
@@ -892,6 +920,50 @@ class GeoGraphyView(OsmGps, NavigationView):
                        self.selection_layer, self.place_list,
                        lat, lon, self.__add_place)
 
+    def add_place_from_kml(self, menu, event, lat, lon):
+        """
+        Add new place(s) from a kml file
+
+        1 - ask for a kml file ?
+        2 - Read the kml file.
+        3 - create the place(s) with name and title found in the kml marker.
+
+        """
+        # Ask for the kml file
+        filter = Gtk.FileFilter()
+        filter.add_pattern("*.kml")
+        kml = Gtk.FileChooserDialog(
+            _("Select a kml file used to add places"),
+            action=Gtk.FileChooserAction.OPEN,
+            buttons=(_('_Cancel'), Gtk.ResponseType.CANCEL,
+                     _('_Apply'), Gtk.ResponseType.OK))
+        mpath = HOME_DIR
+        kml.set_current_folder(os.path.dirname(mpath))
+        kml.set_filter(filter)
+
+        status = kml.run()
+        if status == Gtk.ResponseType.OK:
+            val = conv_to_unicode(kml.get_filename())
+            if val:
+                kmlfile = Kml(val)
+                points = kmlfile.add_points()
+                for place in points:
+                    (name, coords) = place
+                    latlong = coords.pop()
+                    (lat, lon) = latlong
+                    place_name = PlaceName()
+                    place_name.set_value(name)
+                    new_place = Place()
+                    new_place.set_name(place_name)
+                    new_place.set_title(name)
+                    new_place.set_latitude(str(lat))
+                    new_place.set_longitude(str(lon))
+                    try:
+                        EditPlace(self.dbstate, self.uistate, [], new_place)
+                    except WindowActiveError:
+                        pass
+        kml.destroy()
+
     def link_place(self, menu, event, lat, lon):
         """
         Link an existing place using longitude and latitude of location centered
@@ -926,13 +998,16 @@ class GeoGraphyView(OsmGps, NavigationView):
                 from gramps.gui.dialog import WarningDialog
                 WarningDialog(
                       _('You have at least two places with the same title.'),
-                      _("The title of the places is :\n"
-                        "<b>%(title)s</b>\n"
-                        "The following places are similar : %(gid)s\n"
-                        "Eiher you rename the places either you merge them."
-                        "\n\n<b>I can't proceed your request</b>.\n") % {
-                                              'title': place_title,
-                                              'gid': gids}
+                      _("The title of the places is:\n%(title)s\n"
+                        "The following places are similar: %(gid)s\n"
+                        "You should eiher rename the places or merge them.\n\n"
+                        "%(bold_start)s"
+                        "I can't proceed with your request"
+                        "%(bold_end)s.\n") % {
+                            'bold_start' : '<b>',
+                            'bold_end'   : '</b>',
+                            'title': '<b>' + place_title + '</b>',
+                            'gid': gids}
                       )
             else:
                 self.mark = [None, None, None, None, None, None, None,
@@ -1043,12 +1118,12 @@ class GeoGraphyView(OsmGps, NavigationView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(n_rows=2, n_columns=2)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
-        configdialog.add_text(table, _('Nothing for this view.'), 0)
-        return _('Specific parameters'), table
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
+        configdialog.add_text(grid, _('Nothing for this view.'), 0)
+        return _('Specific parameters'), grid
 
     def map_options(self, configdialog):
         """
@@ -1060,36 +1135,35 @@ class GeoGraphyView(OsmGps, NavigationView):
                          config.get('geography.zoom_when_center'))
         self._config.set('geography.max_places',
                          self._config.get('geography.max_places'))
-        table = Gtk.Table(n_rows=1, n_columns=1)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
         self.path_entry = Gtk.Entry()
-        configdialog.add_path_box(table,
+        configdialog.add_path_box(grid,
                 _('Where to save the tiles for offline mode.'),
                 0, self.path_entry, config.get('geography.path'),
                 self.set_tilepath, self.select_tilepath)
-        configdialog.add_text(table,
+        configdialog.add_text(grid,
                 _('If you have no more space in your file system. '
                   'You can remove all tiles placed in the above path.\n'
                   'Be careful! If you have no internet, you\'ll get no map.'),
                 2, line_wrap=False)
-        configdialog.add_slider(table,
+        configdialog.add_slider(grid,
                 _('Zoom used when centering'),
                 3, 'geography.zoom_when_center',
                 (2, 16))
-        configdialog.add_slider(table,
+        configdialog.add_slider(grid,
                 _('The maximum number of places to show'),
                 4, 'geography.max_places',
                 (1000, 10000))
-        configdialog.add_checkbox(table, 
+        configdialog.add_checkbox(grid, 
                 _('Use keypad for shortcuts :\n' 
                   'Either we choose the + and - from the keypad if we select this,\n'
                   'or we use the characters from the keyboard.'),
                 5, 'geography.use-keypad',
                 extra_callback=self.update_shortcuts)
-
-        return _('The map'), table
+        return _('The map'), grid
 
     def set_tilepath(self, *obj):
         if self.path_entry.get_text().strip():
@@ -1101,9 +1175,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         f = Gtk.FileChooserDialog(
             _("Select tile cache directory for offline mode"),
             action=Gtk.FileChooserAction.SELECT_FOLDER,
-            buttons=(Gtk.STOCK_CANCEL,
+            buttons=(_('_Cancel'),
                      Gtk.ResponseType.CANCEL,
-                     Gtk.STOCK_APPLY,
+                     _('_Apply'),
                      Gtk.ResponseType.OK))
         mpath = config.get('geography.path')
         if not mpath:
