@@ -58,6 +58,7 @@ from .lifewaylayer import LifeWayLayer
 from .markerlayer import MarkerLayer
 from .datelayer import DateLayer
 from .messagelayer import MessageLayer
+from .kmllayer import KmlLayer
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.config import config
@@ -90,6 +91,7 @@ class OsmGps():
         self.marker_layer = None
         self.date_layer = None
         self.message_layer = None
+        self.kml_layer = None
         self.context_id = 0
         self.begin_selection = None
         self.end_selection = None
@@ -100,7 +102,7 @@ class OsmGps():
         """
         create the vbox 
         """
-        self.vbox = Gtk.VBox(homogeneous=False, spacing=0)
+        self.vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         cache_path = config.get('geography.path')
         if not os.path.isdir(cache_path):
             try:
@@ -149,6 +151,7 @@ class OsmGps():
         self.osm.layer_add(current_map)
         self.osm.layer_add(DummyLayer())
         self.selection_layer = self.add_selection_layer()
+        self.kml_layer = self.add_kml_layer()
         self.lifeway_layer = self.add_lifeway_layer()
         self.marker_layer = self.add_marker_layer()
         self.date_layer = self.add_date_layer()
@@ -163,10 +166,33 @@ class OsmGps():
         self.osm.connect('button_press_event', self.map_clicked)
         self.osm.connect("motion-notify-event", self.motion_event)
         self.osm.connect('changed', self.zoom_changed)
+        self.update_shortcuts(True)
         self.osm.show()
         self.vbox.pack_start(self.osm, True, True, 0)
         self.goto_handle(handle=None)
 
+    def update_shortcuts(self, arg):
+        """
+        connect the keyboard or the keypad for shortcuts
+        arg is mandatory because this function is also called by the checkbox button
+        """
+        config.set('geography.use-keypad',
+                         self._config.get('geography.use-keypad'))
+        if config.get('geography.use-keypad'):
+            self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.ZOOMIN, Gdk.keyval_from_name("KP_Add"))
+            self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.ZOOMOUT, Gdk.keyval_from_name("KP_Subtract"))
+        else:
+            self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.ZOOMIN, Gdk.keyval_from_name("plus"))
+            self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.ZOOMOUT, Gdk.keyval_from_name("minus"))
+
+        self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.UP, Gdk.keyval_from_name("Up"))
+        self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.DOWN, Gdk.keyval_from_name("Down"))
+        self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.LEFT, Gdk.keyval_from_name("Left"))
+        self.osm.set_keyboard_shortcut(osmgpsmap.MapKey_t.RIGHT, Gdk.keyval_from_name("Right"))
+
+        # For shortcuts work, we must grab the focus
+        self.osm.grab_focus()
+
     def add_selection_layer(self):
         """
         add the selection layer
@@ -181,6 +207,20 @@ class OsmGps():
         """
         return self.selection_layer
 
+    def add_kml_layer(self):
+        """
+        add the kml layer to the map
+        """
+        kml_layer = KmlLayer()
+        self.osm.layer_add(kml_layer)
+        return kml_layer
+
+    def get_kml_layer(self):
+        """
+        get the kml layer
+        """
+        return self.kml_layer
+
     def add_message_layer(self):
         """
         add the message layer to the map
@@ -309,6 +349,7 @@ class OsmGps():
         mouse button 2 : begin zone selection
         mouse button 3 : call the menu
         """
+        self.osm.grab_focus()
         lat, lon = self.osm.get_event_location(event).get_degrees()
         current = osm.convert_screen_to_geographic(int(event.x), int(event.y))
         lat, lon = current.get_degrees()
@@ -397,10 +438,10 @@ class OsmGps():
         Show or hide the crosshair ?
         """
         if active:
+            self.osm.layer_remove(self.cross_map)
             self.cross_map = osmgpsmap.MapOsd( show_crosshair=True)
             self.osm.layer_add( self.cross_map )
-            # The two following are to force the map to update
-            self.osm.zoom_in()
-            self.osm.zoom_out()
         else:
             self.osm.layer_remove(self.cross_map)
+            self.cross_map = osmgpsmap.MapOsd( show_crosshair=False)
+            self.osm.layer_add( self.cross_map )
