@@ -190,26 +190,8 @@ class IndivCompleteReport(Report):
             self.doc.end_superscript()
         self.doc.end_paragraph()
         
-        attr_list = event.get_attribute_list()
-        if len(attr_list):
-            for attr in attr_list:
-                attr_type = self._get_type(attr.get_type())
-                # translators: needed for French, ignore otherwise
-                text = self._("%(type)s: %(value)s") % {
-                                    'type'  : self._(attr_type),
-                                    'value' : attr.get_value() }
-                endnotes = self._cite_endnote(attr)
-                self.write_paragraph(text, endnotes)
-
-        attr_list = event_ref.get_attribute_list()
-        if len(attr_list):
-            for attr in attr_list:
-                # translators: needed for French, ignore otherwise
-                text = self._("%(type)s: %(value)s") % {
-                                    'type'  : self._(str(attr.get_type())),
-                                    'value' : attr.get_value() }
-                endnotes = self._cite_endnote(attr)
-                self.write_paragraph(text, endnotes)
+        self.do_attributes(event.get_attribute_list() +
+                           event_ref.get_attribute_list() )
 
         for notehandle in event.get_note_list():
             note = self._db.get_note_from_handle(notehandle)
@@ -413,7 +395,7 @@ class IndivCompleteReport(Report):
         self.doc.end_row()
         
         for attr in attr_list:
-            attr_type = self._get_type(attr.get_type())
+            attr_type = attr.get_type().type2base()
             self.doc.start_row()
             self.write_cell(self._(attr_type))
             text = attr.get_value()
@@ -490,7 +472,7 @@ class IndivCompleteReport(Report):
             tags.append(tag.get_name())
         for text in sorted(tags):
             self.doc.start_row()
-            self.write_cell(text)
+            self.write_cell(text, span=2)
             self.doc.end_row()
         self.doc.end_table()
         self.doc.start_paragraph('IDS-Normal')
@@ -499,9 +481,26 @@ class IndivCompleteReport(Report):
     def write_images(self):
 
         media_list = self.person.get_media_list()
-        if (not self.use_images) or (len(media_list) < 2): # only show if > one
+        if (not self.use_images) or (not media_list):
             return
-        
+
+        i_total = 0
+        for media_ref in media_list:
+            media_handle = media_ref.get_reference_handle()
+            if media_handle:
+                media = self._db.get_object_from_handle(media_handle)
+                if media and media.get_mime_type():
+                    if media.get_mime_type().startswith("image"):
+                        i_total += 1
+        if i_total == 0:
+            return
+        # if there is only one image, and it is the first Gallery item, it
+        # will be shown up at the top, so there's no reason to show it here;
+        # but if there's only one image and it is not the first Gallery
+        # item (maybe the first is a PDF, say), then we need to show it
+        if ((i_total == 1) and self.mime0 and self.mime0.startswith("image")):
+            return
+
         self.doc.start_table("images","IDS-GalleryTable")
         cells = 3 # the GalleryTable has 3 cells
         self.doc.start_row()
@@ -509,9 +508,10 @@ class IndivCompleteReport(Report):
         self.write_paragraph(self._('Images'), style='IDS-TableTitle')
         self.doc.end_cell()
         self.doc.end_row()
-        count = 0
-        while ( count < len(media_list) ):
-            media_ref = media_list[count]
+        media_count = 0
+        image_count = 0
+        while ( media_count < len(media_list) ):
+            media_ref = media_list[media_count]
             media_handle = media_ref.get_reference_handle()
             media = self._db.get_object_from_handle(media_handle)
             if media is None:
@@ -520,20 +520,23 @@ class IndivCompleteReport(Report):
                 return
             mime_type = media.get_mime_type()
             if not mime_type or not mime_type.startswith("image"):
-                count += 1
+                media_count += 1
                 continue
             description = media.get_description()
-            if count % cells == 0:
+            if image_count % cells == 0:
                 self.doc.start_row()
             self.doc.start_cell('IDS-NormalCell')
             self.write_paragraph(description, style='IDS-ImageCaptionCenter')
             ReportUtils.insert_image(self._db, self.doc, media_ref, self._user,
                                      align='center', w_cm=5.0, h_cm=5.0)
+            self.do_attributes(media.get_attribute_list() +
+                               media_ref.get_attribute_list() )
             self.doc.end_cell()
-            if count % cells == cells - 1:
+            if image_count % cells == cells - 1:
                 self.doc.end_row()
-            count += 1
-        if count % cells != 0:
+            media_count += 1
+            image_count += 1
+        if image_count % cells != 0:
             self.doc.end_row()
         self.doc.end_table()
         self.doc.start_paragraph('IDS-Normal')
@@ -601,14 +604,7 @@ class IndivCompleteReport(Report):
                 self.doc.start_row()
                 self.write_cell(self._("Attributes"))
                 self.doc.start_cell("IDS-ListCell")
-                for attr in attr_list:
-                    attr_type = self._get_type(attr.get_type())
-                    # translators: needed for French, ignore otherwise
-                    text = self._("%(type)s: %(value)s") % {
-                                        'type'  : self._(attr_type),
-                                        'value' : attr.get_value() }
-                    endnotes = self._cite_endnote(attr)
-                    self.write_paragraph(text, endnotes)
+                self.do_attributes(attr_list)
                 self.doc.end_cell()
                 self.doc.end_row()
 
@@ -712,8 +708,9 @@ class IndivCompleteReport(Report):
             if group in event_dict:
                 self.write_section(event_dict[group], group)
 
-    def write_cell(self, text, endnotes=None, mark=None, style='IDS-Normal'):
-        self.doc.start_cell('IDS-NormalCell')
+    def write_cell(self, text,
+                   endnotes=None, mark=None, style='IDS-Normal', span=1):
+        self.doc.start_cell('IDS-NormalCell', span)
         self.write_paragraph(text, endnotes=endnotes, mark=mark, style=style)
         self.doc.end_cell()
 
@@ -789,12 +786,13 @@ class IndivCompleteReport(Report):
 
         media_list = self.person.get_media_list()
         p_style = 'IDS-PersonTable2'
+        self.mime0 = None
         if self.use_images and len(media_list) > 0:
             media0 = media_list[0]
             media_handle = media0.get_reference_handle()
             media = self._db.get_object_from_handle(media_handle)
-            mime_type = media.get_mime_type()
-            if mime_type and mime_type.startswith("image"):
+            self.mime0 = media.get_mime_type()
+            if self.mime0 and self.mime0.startswith("image"):
                 image_filename = media_path_full(self._db, media.get_path())
                 if os.path.exists(image_filename):
                     p_style = 'IDS-PersonTable' # this is tested for, also
@@ -839,7 +837,7 @@ class IndivCompleteReport(Report):
                 text = _('(image)')
             else:
                 for attr in attr_list:
-                    attr_type = self._get_type(attr.get_type())
+                    attr_type = attr.get_type().type2base()
                     # translators: needed for French, ignore otherwise
                     text = self._("%(str1)s: %(str2)s") % {
                                         'str1' : self._(attr_type),
@@ -903,6 +901,16 @@ class IndivCompleteReport(Report):
             txt = self._('%(str1)s, %(str2)s') % {'str1':prior, 'str2':txt}
         return txt
 
+    def do_attributes(self, attr_list):
+        for attr in attr_list:
+            attr_type = attr.get_type().type2base()
+            # translators: needed for French, ignore otherwise
+            text = self._("%(type)s: %(value)s") % {
+                                'type'  : self._(attr_type),
+                                'value' : attr.get_value() }
+            endnotes = self._cite_endnote(attr)
+            self.write_paragraph(text, endnotes)
+
 #------------------------------------------------------------------------
 #
 # IndivCompleteOptions
