@@ -100,11 +100,11 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         self.set_fan(fanchartdesc.FanChartDescWidget(self.dbstate, self.uistate,
                                                      self.on_popup))
         self.scrolledwindow = Gtk.ScrolledWindow(hadjustment=None,
-                                                                        vadjustment=None)
+                                                 vadjustment=None)
         self.scrolledwindow.set_policy(Gtk.PolicyType.AUTOMATIC,
                                        Gtk.PolicyType.AUTOMATIC)
         self.fan.show_all()
-        self.scrolledwindow.add_with_viewport(self.fan)
+        self.scrolledwindow.add(self.fan)
 
         return self.scrolledwindow
 
@@ -163,9 +163,9 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         """
         NavigationView.define_actions(self)
 
-        self._add_action('PrintView', Gtk.STOCK_PRINT, _("_Print..."), 
-                         accel="<PRIMARY>P", 
-                         tip=_("Print or save the Fan Chart View"), 
+        self._add_action('PrintView', 'document-print', _("_Print..."),
+                         accel="<PRIMARY>P",
+                         tip=_("Print or save the Fan Chart View"),
                          callback=self.printview)
     def build_tree(self):
         """
@@ -266,15 +266,15 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
         Function that builds the widget in the configuration dialog
         """
         nrentry = 8
-        table = Gtk.Table(n_rows=6, n_columns=3)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
 
-        configdialog.add_spinner(table, _("Max generations"), 0,
-                'interface.fanview-maxgen', (1, 11), 
+        configdialog.add_spinner(grid, _("Max generations"), 0,
+                'interface.fanview-maxgen', (2, 11),
                 callback=self.cb_update_maxgen)
-        configdialog.add_combo(table, 
+        configdialog.add_combo(grid, 
                 _('Text Font'), 
                 1, 'interface.fanview-font',
                 self.allfonts, callback=self.cb_update_font, valueactive=True)
@@ -295,7 +295,7 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
             if curval == nr:
                 break
             nrval += 1
-        configdialog.add_combo(table, 
+        configdialog.add_combo(grid, 
                 _('Background'), 
                 2, 'interface.fanview-background',
                 backgrvals,
@@ -303,21 +303,21 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
                 setactive=nrval
                 )
         #colors, stored as hex values
-        configdialog.add_color(table, _('Start gradient/Main color'), 3, 
+        configdialog.add_color(grid, _('Start gradient/Main color'), 3, 
                         'interface.color-start-grad', col=1)
-        configdialog.add_color(table, _('End gradient/2nd color'), 4, 
+        configdialog.add_color(grid, _('End gradient/2nd color'), 4, 
                         'interface.color-end-grad',  col=1)
-        configdialog.add_color(table, _('Color for duplicates'), 5,
+        configdialog.add_color(grid, _('Color for duplicates'), 5,
                         'interface.duplicate-color', col=1)
         # form of the fan
-        configdialog.add_combo(table, _('Fan chart type'), 6,
+        configdialog.add_combo(grid, _('Fan chart type'), 6,
                         'interface.fanview-form',
                         ((fanchart.FORM_CIRCLE, _('Full Circle')),
                          (fanchart.FORM_HALFCIRCLE, _('Half Circle')), 
                          (fanchart.FORM_QUADRANT, _('Quadrant'))),
                         callback=self.cb_update_form)
         # algo for the fan angle distribution
-        configdialog.add_combo(table, _('Fan chart distribution'), 7,
+        configdialog.add_combo(grid, _('Fan chart distribution'), 7,
                         'interface.angle-algorithm',
                         ((fanchartdesc.ANGLE_CHEQUI, 
                           _('Homogeneous children distribution')),
@@ -326,7 +326,7 @@ class FanChartDescView(fanchartdesc.FanChartDescGrampsGUI, NavigationView):
                         ),
                         callback=self.cb_update_anglealgo)
 
-        return _('Layout'), table
+        return _('Layout'), grid
 
     def config_connect(self):
         """
